/*******************************************************************************
* Copyright 2014-2020 Intel Corporation
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*******************************************************************************/


#define SWIGPYTHON
#define SWIG_DIRECTORS
#define SWIG_PYTHON_THREADS


#ifdef __cplusplus
/* SwigValueWrapper is described in swig.swg */
template<typename T> class SwigValueWrapper {
  struct SwigMovePointer {
    T *ptr;
    SwigMovePointer(T *p) : ptr(p) { }
    ~SwigMovePointer() { delete ptr; }
    SwigMovePointer& operator=(SwigMovePointer& rhs) { T* oldptr = ptr; ptr = 0; delete oldptr; ptr = rhs.ptr; rhs.ptr = 0; return *this; }
  } pointer;
  SwigValueWrapper& operator=(const SwigValueWrapper<T>& rhs);
  SwigValueWrapper(const SwigValueWrapper<T>& rhs);
public:
  SwigValueWrapper() : pointer(0) { }
  SwigValueWrapper& operator=(const T& t) { SwigMovePointer tmp(new T(t)); pointer = tmp; return *this; }
  operator T&() const { return *pointer.ptr; }
  T *operator&() { return pointer.ptr; }
};

template <typename T> T SwigValueInit() {
  return T();
}
#endif

/* -----------------------------------------------------------------------------
 *  This section contains generic SWIG labels for method/variable
 *  declarations/attributes, and other compiler dependent labels.
 * ----------------------------------------------------------------------------- */

/* template workaround for compilers that cannot correctly implement the C++ standard */
#ifndef SWIGTEMPLATEDISAMBIGUATOR
# if defined(__SUNPRO_CC) && (__SUNPRO_CC <= 0x560)
#  define SWIGTEMPLATEDISAMBIGUATOR template
# elif defined(__HP_aCC)
/* Needed even with `aCC -AA' when `aCC -V' reports HP ANSI C++ B3910B A.03.55 */
/* If we find a maximum version that requires this, the test would be __HP_aCC <= 35500 for A.03.55 */
#  define SWIGTEMPLATEDISAMBIGUATOR template
# else
#  define SWIGTEMPLATEDISAMBIGUATOR
# endif
#endif

/* inline attribute */
#ifndef SWIGINLINE
# if defined(__cplusplus) || (defined(__GNUC__) && !defined(__STRICT_ANSI__))
#   define SWIGINLINE inline
# else
#   define SWIGINLINE
# endif
#endif

/* attribute recognised by some compilers to avoid 'unused' warnings */
#ifndef SWIGUNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define SWIGUNUSED __attribute__ ((__unused__))
#   else
#     define SWIGUNUSED
#   endif
# elif defined(__ICC)
#   define SWIGUNUSED __attribute__ ((__unused__))
# else
#   define SWIGUNUSED
# endif
#endif

#ifndef SWIG_MSC_UNSUPPRESS_4505
# if defined(_MSC_VER)
#   pragma warning(disable : 4505) /* unreferenced local function has been removed */
# endif
#endif

#ifndef SWIGUNUSEDPARM
# ifdef __cplusplus
#   define SWIGUNUSEDPARM(p)
# else
#   define SWIGUNUSEDPARM(p) p SWIGUNUSED
# endif
#endif

/* internal SWIG method */
#ifndef SWIGINTERN
# define SWIGINTERN static SWIGUNUSED
#endif

/* internal inline SWIG method */
#ifndef SWIGINTERNINLINE
# define SWIGINTERNINLINE SWIGINTERN SWIGINLINE
#endif

/* exporting methods */
#if (__GNUC__ >= 4) || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4)
#  ifndef GCC_HASCLASSVISIBILITY
#    define GCC_HASCLASSVISIBILITY
#  endif
#endif

#ifndef SWIGEXPORT
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   if defined(STATIC_LINKED)
#     define SWIGEXPORT
#   else
#     define SWIGEXPORT __declspec(dllexport)
#   endif
# else
#   if defined(__GNUC__) && defined(GCC_HASCLASSVISIBILITY)
#     define SWIGEXPORT __attribute__ ((visibility("default")))
#   else
#     define SWIGEXPORT
#   endif
# endif
#endif

/* calling conventions for Windows */
#ifndef SWIGSTDCALL
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   define SWIGSTDCALL __stdcall
# else
#   define SWIGSTDCALL
# endif
#endif

/* Deal with Microsoft's attempt at deprecating C standard runtime functions */
#if !defined(SWIG_NO_CRT_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_CRT_SECURE_NO_DEPRECATE)
# define _CRT_SECURE_NO_DEPRECATE
#endif

/* Deal with Microsoft's attempt at deprecating methods in the standard C++ library */
#if !defined(SWIG_NO_SCL_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_SCL_SECURE_NO_DEPRECATE)
# define _SCL_SECURE_NO_DEPRECATE
#endif

/* Deal with Apple's deprecated 'AssertMacros.h' from Carbon-framework */
#if defined(__APPLE__) && !defined(__ASSERT_MACROS_DEFINE_VERSIONS_WITHOUT_UNDERSCORES)
# define __ASSERT_MACROS_DEFINE_VERSIONS_WITHOUT_UNDERSCORES 0
#endif

/* Intel's compiler complains if a variable which was never initialised is
 * cast to void, which is a common idiom which we use to indicate that we
 * are aware a variable isn't used.  So we just silence that warning.
 * See: https://github.com/swig/swig/issues/192 for more discussion.
 */
#ifdef __INTEL_COMPILER
# pragma warning disable 592
#endif


#if defined(_DEBUG) && defined(SWIG_PYTHON_INTERPRETER_NO_DEBUG)
/* Use debug wrappers with the Python release dll */
# undef _DEBUG
# include <Python.h>
# define _DEBUG
#else
# include <Python.h>
#endif

/* -----------------------------------------------------------------------------
 * swigrun.swg
 *
 * This file contains generic C API SWIG runtime support for pointer
 * type checking.
 * ----------------------------------------------------------------------------- */

/* This should only be incremented when either the layout of swig_type_info changes,
   or for whatever reason, the runtime changes incompatibly */
#define SWIG_RUNTIME_VERSION "4"

/* define SWIG_TYPE_TABLE_NAME as "SWIG_TYPE_TABLE" */
#ifdef SWIG_TYPE_TABLE
# define SWIG_QUOTE_STRING(x) #x
# define SWIG_EXPAND_AND_QUOTE_STRING(x) SWIG_QUOTE_STRING(x)
# define SWIG_TYPE_TABLE_NAME SWIG_EXPAND_AND_QUOTE_STRING(SWIG_TYPE_TABLE)
#else
# define SWIG_TYPE_TABLE_NAME
#endif

/*
  You can use the SWIGRUNTIME and SWIGRUNTIMEINLINE macros for
  creating a static or dynamic library from the SWIG runtime code.
  In 99.9% of the cases, SWIG just needs to declare them as 'static'.

  But only do this if strictly necessary, ie, if you have problems
  with your compiler or suchlike.
*/

#ifndef SWIGRUNTIME
# define SWIGRUNTIME SWIGINTERN
#endif

#ifndef SWIGRUNTIMEINLINE
# define SWIGRUNTIMEINLINE SWIGRUNTIME SWIGINLINE
#endif

/*  Generic buffer size */
#ifndef SWIG_BUFFER_SIZE
# define SWIG_BUFFER_SIZE 1024
#endif

/* Flags for pointer conversions */
#define SWIG_POINTER_DISOWN        0x1
#define SWIG_CAST_NEW_MEMORY       0x2

/* Flags for new pointer objects */
#define SWIG_POINTER_OWN           0x1


/*
   Flags/methods for returning states.

   The SWIG conversion methods, as ConvertPtr, return an integer
   that tells if the conversion was successful or not. And if not,
   an error code can be returned (see swigerrors.swg for the codes).

   Use the following macros/flags to set or process the returning
   states.

   In old versions of SWIG, code such as the following was usually written:

     if (SWIG_ConvertPtr(obj,vptr,ty.flags) != -1) {
       // success code
     } else {
       //fail code
     }

   Now you can be more explicit:

    int res = SWIG_ConvertPtr(obj,vptr,ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
    } else {
      // fail code
    }

   which is the same really, but now you can also do

    Type *ptr;
    int res = SWIG_ConvertPtr(obj,(void **)(&ptr),ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
      if (SWIG_IsNewObj(res) {
        ...
	delete *ptr;
      } else {
        ...
      }
    } else {
      // fail code
    }

   I.e., now SWIG_ConvertPtr can return new objects and you can
   identify the case and take care of the deallocation. Of course that
   also requires SWIG_ConvertPtr to return new result values, such as

      int SWIG_ConvertPtr(obj, ptr,...) {
        if (<obj is ok>) {
          if (<need new object>) {
            *ptr = <ptr to new allocated object>;
            return SWIG_NEWOBJ;
          } else {
            *ptr = <ptr to old object>;
            return SWIG_OLDOBJ;
          }
        } else {
          return SWIG_BADOBJ;
        }
      }

   Of course, returning the plain '0(success)/-1(fail)' still works, but you can be
   more explicit by returning SWIG_BADOBJ, SWIG_ERROR or any of the
   SWIG errors code.

   Finally, if the SWIG_CASTRANK_MODE is enabled, the result code
   allows to return the 'cast rank', for example, if you have this

       int food(double)
       int fooi(int);

   and you call

      food(1)   // cast rank '1'  (1 -> 1.0)
      fooi(1)   // cast rank '0'

   just use the SWIG_AddCast()/SWIG_CheckState()
*/

#define SWIG_OK                    (0)
#define SWIG_ERROR                 (-1)
#define SWIG_IsOK(r)               (r >= 0)
#define SWIG_ArgError(r)           ((r != SWIG_ERROR) ? r : SWIG_TypeError)

/* The CastRankLimit says how many bits are used for the cast rank */
#define SWIG_CASTRANKLIMIT         (1 << 8)
/* The NewMask denotes the object was created (using new/malloc) */
#define SWIG_NEWOBJMASK            (SWIG_CASTRANKLIMIT  << 1)
/* The TmpMask is for in/out typemaps that use temporal objects */
#define SWIG_TMPOBJMASK            (SWIG_NEWOBJMASK << 1)
/* Simple returning values */
#define SWIG_BADOBJ                (SWIG_ERROR)
#define SWIG_OLDOBJ                (SWIG_OK)
#define SWIG_NEWOBJ                (SWIG_OK | SWIG_NEWOBJMASK)
#define SWIG_TMPOBJ                (SWIG_OK | SWIG_TMPOBJMASK)
/* Check, add and del mask methods */
#define SWIG_AddNewMask(r)         (SWIG_IsOK(r) ? (r | SWIG_NEWOBJMASK) : r)
#define SWIG_DelNewMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_NEWOBJMASK) : r)
#define SWIG_IsNewObj(r)           (SWIG_IsOK(r) && (r & SWIG_NEWOBJMASK))
#define SWIG_AddTmpMask(r)         (SWIG_IsOK(r) ? (r | SWIG_TMPOBJMASK) : r)
#define SWIG_DelTmpMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_TMPOBJMASK) : r)
#define SWIG_IsTmpObj(r)           (SWIG_IsOK(r) && (r & SWIG_TMPOBJMASK))

/* Cast-Rank Mode */
#if defined(SWIG_CASTRANK_MODE)
#  ifndef SWIG_TypeRank
#    define SWIG_TypeRank             unsigned long
#  endif
#  ifndef SWIG_MAXCASTRANK            /* Default cast allowed */
#    define SWIG_MAXCASTRANK          (2)
#  endif
#  define SWIG_CASTRANKMASK          ((SWIG_CASTRANKLIMIT) -1)
#  define SWIG_CastRank(r)           (r & SWIG_CASTRANKMASK)
SWIGINTERNINLINE int SWIG_AddCast(int r) {
  return SWIG_IsOK(r) ? ((SWIG_CastRank(r) < SWIG_MAXCASTRANK) ? (r + 1) : SWIG_ERROR) : r;
}
SWIGINTERNINLINE int SWIG_CheckState(int r) {
  return SWIG_IsOK(r) ? SWIG_CastRank(r) + 1 : 0;
}
#else /* no cast-rank mode */
#  define SWIG_AddCast(r) (r)
#  define SWIG_CheckState(r) (SWIG_IsOK(r) ? 1 : 0)
#endif


#include <string.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef void *(*swig_converter_func)(void *, int *);
typedef struct swig_type_info *(*swig_dycast_func)(void **);

/* Structure to store information on one type */
typedef struct swig_type_info {
  const char             *name;			/* mangled name of this type */
  const char             *str;			/* human readable name of this type */
  swig_dycast_func        dcast;		/* dynamic cast function down a hierarchy */
  struct swig_cast_info  *cast;			/* linked list of types that can cast into this type */
  void                   *clientdata;		/* language specific type data */
  int                    owndata;		/* flag if the structure owns the clientdata */
} swig_type_info;

/* Structure to store a type and conversion function used for casting */
typedef struct swig_cast_info {
  swig_type_info         *type;			/* pointer to type that is equivalent to this type */
  swig_converter_func     converter;		/* function to cast the void pointers */
  struct swig_cast_info  *next;			/* pointer to next cast in linked list */
  struct swig_cast_info  *prev;			/* pointer to the previous cast */
} swig_cast_info;

/* Structure used to store module information
 * Each module generates one structure like this, and the runtime collects
 * all of these structures and stores them in a circularly linked list.*/
typedef struct swig_module_info {
  swig_type_info         **types;		/* Array of pointers to swig_type_info structures that are in this module */
  size_t                 size;		        /* Number of types in this module */
  struct swig_module_info *next;		/* Pointer to next element in circularly linked list */
  swig_type_info         **type_initial;	/* Array of initially generated type structures */
  swig_cast_info         **cast_initial;	/* Array of initially generated casting structures */
  void                    *clientdata;		/* Language specific module data */
} swig_module_info;

/*
  Compare two type names skipping the space characters, therefore
  "char*" == "char *" and "Class<int>" == "Class<int >", etc.

  Return 0 when the two name types are equivalent, as in
  strncmp, but skipping ' '.
*/
SWIGRUNTIME int
SWIG_TypeNameComp(const char *f1, const char *l1,
		  const char *f2, const char *l2) {
  for (;(f1 != l1) && (f2 != l2); ++f1, ++f2) {
    while ((*f1 == ' ') && (f1 != l1)) ++f1;
    while ((*f2 == ' ') && (f2 != l2)) ++f2;
    if (*f1 != *f2) return (*f1 > *f2) ? 1 : -1;
  }
  return (int)((l1 - f1) - (l2 - f2));
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if equal, -1 if nb < tb, 1 if nb > tb
*/
SWIGRUNTIME int
SWIG_TypeCmp(const char *nb, const char *tb) {
  int equiv = 1;
  const char* te = tb + strlen(tb);
  const char* ne = nb;
  while (equiv != 0 && *ne) {
    for (nb = ne; *ne; ++ne) {
      if (*ne == '|') break;
    }
    equiv = SWIG_TypeNameComp(nb, ne, tb, te);
    if (*ne) ++ne;
  }
  return equiv;
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if not equal, 1 if equal
*/
SWIGRUNTIME int
SWIG_TypeEquiv(const char *nb, const char *tb) {
  return SWIG_TypeCmp(nb, tb) == 0 ? 1 : 0;
}

/*
  Check the typename
*/
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheck(const char *c, swig_type_info *ty) {
  if (ty) {
    swig_cast_info *iter = ty->cast;
    while (iter) {
      if (strcmp(iter->type->name, c) == 0) {
        if (iter == ty->cast)
          return iter;
        /* Move iter to the top of the linked list */
        iter->prev->next = iter->next;
        if (iter->next)
          iter->next->prev = iter->prev;
        iter->next = ty->cast;
        iter->prev = 0;
        if (ty->cast) ty->cast->prev = iter;
        ty->cast = iter;
        return iter;
      }
      iter = iter->next;
    }
  }
  return 0;
}

/*
  Identical to SWIG_TypeCheck, except strcmp is replaced with a pointer comparison
*/
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheckStruct(swig_type_info *from, swig_type_info *ty) {
  if (ty) {
    swig_cast_info *iter = ty->cast;
    while (iter) {
      if (iter->type == from) {
        if (iter == ty->cast)
          return iter;
        /* Move iter to the top of the linked list */
        iter->prev->next = iter->next;
        if (iter->next)
          iter->next->prev = iter->prev;
        iter->next = ty->cast;
        iter->prev = 0;
        if (ty->cast) ty->cast->prev = iter;
        ty->cast = iter;
        return iter;
      }
      iter = iter->next;
    }
  }
  return 0;
}

/*
  Cast a pointer up an inheritance hierarchy
*/
SWIGRUNTIMEINLINE void *
SWIG_TypeCast(swig_cast_info *ty, void *ptr, int *newmemory) {
  return ((!ty) || (!ty->converter)) ? ptr : (*ty->converter)(ptr, newmemory);
}

/*
   Dynamic pointer casting. Down an inheritance hierarchy
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeDynamicCast(swig_type_info *ty, void **ptr) {
  swig_type_info *lastty = ty;
  if (!ty || !ty->dcast) return ty;
  while (ty && (ty->dcast)) {
    ty = (*ty->dcast)(ptr);
    if (ty) lastty = ty;
  }
  return lastty;
}

/*
  Return the name associated with this type
*/
SWIGRUNTIMEINLINE const char *
SWIG_TypeName(const swig_type_info *ty) {
  return ty->name;
}

/*
  Return the pretty name associated with this type,
  that is an unmangled type name in a form presentable to the user.
*/
SWIGRUNTIME const char *
SWIG_TypePrettyName(const swig_type_info *type) {
  /* The "str" field contains the equivalent pretty names of the
     type, separated by vertical-bar characters.  We choose
     to print the last name, as it is often (?) the most
     specific. */
  if (!type) return NULL;
  if (type->str != NULL) {
    const char *last_name = type->str;
    const char *s;
    for (s = type->str; *s; s++)
      if (*s == '|') last_name = s+1;
    return last_name;
  }
  else
    return type->name;
}

/*
   Set the clientdata field for a type
*/
SWIGRUNTIME void
SWIG_TypeClientData(swig_type_info *ti, void *clientdata) {
  swig_cast_info *cast = ti->cast;
  /* if (ti->clientdata == clientdata) return; */
  ti->clientdata = clientdata;

  while (cast) {
    if (!cast->converter) {
      swig_type_info *tc = cast->type;
      if (!tc->clientdata) {
	SWIG_TypeClientData(tc, clientdata);
      }
    }
    cast = cast->next;
  }
}
SWIGRUNTIME void
SWIG_TypeNewClientData(swig_type_info *ti, void *clientdata) {
  SWIG_TypeClientData(ti, clientdata);
  ti->owndata = 1;
}

/*
  Search for a swig_type_info structure only by mangled name
  Search is a O(log #types)

  We start searching at module start, and finish searching when start == end.
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_MangledTypeQueryModule(swig_module_info *start,
                            swig_module_info *end,
		            const char *name) {
  swig_module_info *iter = start;
  do {
    if (iter->size) {
      size_t l = 0;
      size_t r = iter->size - 1;
      do {
	/* since l+r >= 0, we can (>> 1) instead (/ 2) */
	size_t i = (l + r) >> 1;
	const char *iname = iter->types[i]->name;
	if (iname) {
	  int compare = strcmp(name, iname);
	  if (compare == 0) {
	    return iter->types[i];
	  } else if (compare < 0) {
	    if (i) {
	      r = i - 1;
	    } else {
	      break;
	    }
	  } else if (compare > 0) {
	    l = i + 1;
	  }
	} else {
	  break; /* should never happen */
	}
      } while (l <= r);
    }
    iter = iter->next;
  } while (iter != end);
  return 0;
}

/*
  Search for a swig_type_info structure for either a mangled name or a human readable name.
  It first searches the mangled names of the types, which is a O(log #types)
  If a type is not found it then searches the human readable names, which is O(#types).

  We start searching at module start, and finish searching when start == end.
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeQueryModule(swig_module_info *start,
                     swig_module_info *end,
		     const char *name) {
  /* STEP 1: Search the name field using binary search */
  swig_type_info *ret = SWIG_MangledTypeQueryModule(start, end, name);
  if (ret) {
    return ret;
  } else {
    /* STEP 2: If the type hasn't been found, do a complete search
       of the str field (the human readable name) */
    swig_module_info *iter = start;
    do {
      size_t i = 0;
      for (; i < iter->size; ++i) {
	if (iter->types[i]->str && (SWIG_TypeEquiv(iter->types[i]->str, name)))
	  return iter->types[i];
      }
      iter = iter->next;
    } while (iter != end);
  }

  /* neither found a match */
  return 0;
}

/*
   Pack binary data into a string
*/
SWIGRUNTIME char *
SWIG_PackData(char *c, void *ptr, size_t sz) {
  static const char hex[17] = "0123456789abcdef";
  const unsigned char *u = (unsigned char *) ptr;
  const unsigned char *eu =  u + sz;
  for (; u != eu; ++u) {
    unsigned char uu = *u;
    *(c++) = hex[(uu & 0xf0) >> 4];
    *(c++) = hex[uu & 0xf];
  }
  return c;
}

/*
   Unpack binary data from a string
*/
SWIGRUNTIME const char *
SWIG_UnpackData(const char *c, void *ptr, size_t sz) {
  unsigned char *u = (unsigned char *) ptr;
  const unsigned char *eu = u + sz;
  for (; u != eu; ++u) {
    char d = *(c++);
    unsigned char uu;
    if ((d >= '0') && (d <= '9'))
      uu = ((d - '0') << 4);
    else if ((d >= 'a') && (d <= 'f'))
      uu = ((d - ('a'-10)) << 4);
    else
      return (char *) 0;
    d = *(c++);
    if ((d >= '0') && (d <= '9'))
      uu |= (d - '0');
    else if ((d >= 'a') && (d <= 'f'))
      uu |= (d - ('a'-10));
    else
      return (char *) 0;
    *u = uu;
  }
  return c;
}

/*
   Pack 'void *' into a string buffer.
*/
SWIGRUNTIME char *
SWIG_PackVoidPtr(char *buff, void *ptr, const char *name, size_t bsz) {
  char *r = buff;
  if ((2*sizeof(void *) + 2) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,&ptr,sizeof(void *));
  if (strlen(name) + 1 > (bsz - (r - buff))) return 0;
  strcpy(r,name);
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackVoidPtr(const char *c, void **ptr, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      *ptr = (void *) 0;
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sizeof(void *));
}

SWIGRUNTIME char *
SWIG_PackDataName(char *buff, void *ptr, size_t sz, const char *name, size_t bsz) {
  char *r = buff;
  size_t lname = (name ? strlen(name) : 0);
  if ((2*sz + 2 + lname) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,ptr,sz);
  if (lname) {
    strncpy(r,name,lname+1);
  } else {
    *r = 0;
  }
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackDataName(const char *c, void *ptr, size_t sz, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      memset(ptr,0,sz);
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sz);
}

#ifdef __cplusplus
}
#endif

/*  Errors in SWIG */
#define  SWIG_UnknownError    	   -1
#define  SWIG_IOError        	   -2
#define  SWIG_RuntimeError   	   -3
#define  SWIG_IndexError     	   -4
#define  SWIG_TypeError      	   -5
#define  SWIG_DivisionByZero 	   -6
#define  SWIG_OverflowError  	   -7
#define  SWIG_SyntaxError    	   -8
#define  SWIG_ValueError     	   -9
#define  SWIG_SystemError    	   -10
#define  SWIG_AttributeError 	   -11
#define  SWIG_MemoryError    	   -12
#define  SWIG_NullReferenceError   -13



/* Compatibility macros for Python 3 */
#if PY_VERSION_HEX >= 0x03000000

#define PyClass_Check(obj) PyObject_IsInstance(obj, (PyObject *)&PyType_Type)
#define PyInt_Check(x) PyLong_Check(x)
#define PyInt_AsLong(x) PyLong_AsLong(x)
#define PyInt_FromLong(x) PyLong_FromLong(x)
#define PyInt_FromSize_t(x) PyLong_FromSize_t(x)
#define PyString_Check(name) PyBytes_Check(name)
#define PyString_FromString(x) PyUnicode_FromString(x)
#define PyString_Format(fmt, args)  PyUnicode_Format(fmt, args)
#define PyString_AsString(str) PyBytes_AsString(str)
#define PyString_Size(str) PyBytes_Size(str)	
#define PyString_InternFromString(key) PyUnicode_InternFromString(key)
#define Py_TPFLAGS_HAVE_CLASS Py_TPFLAGS_BASETYPE
#define PyString_AS_STRING(x) PyUnicode_AS_STRING(x)
#define _PyLong_FromSsize_t(x) PyLong_FromSsize_t(x)

#endif

#ifndef Py_TYPE
#  define Py_TYPE(op) ((op)->ob_type)
#endif

/* SWIG APIs for compatibility of both Python 2 & 3 */

#if PY_VERSION_HEX >= 0x03000000
#  define SWIG_Python_str_FromFormat PyUnicode_FromFormat
#else
#  define SWIG_Python_str_FromFormat PyString_FromFormat
#endif


/* Warning: This function will allocate a new string in Python 3,
 * so please call SWIG_Python_str_DelForPy3(x) to free the space.
 */
SWIGINTERN char*
SWIG_Python_str_AsChar(PyObject *str)
{
#if PY_VERSION_HEX >= 0x03000000
  char *cstr;
  char *newstr;
  Py_ssize_t len;
  str = PyUnicode_AsUTF8String(str);
  PyBytes_AsStringAndSize(str, &cstr, &len);
  newstr = (char *) malloc(len+1);
  memcpy(newstr, cstr, len+1);
  Py_XDECREF(str);
  return newstr;
#else
  return PyString_AsString(str);
#endif
}

#if PY_VERSION_HEX >= 0x03000000
#  define SWIG_Python_str_DelForPy3(x) free( (void*) (x) )
#else
#  define SWIG_Python_str_DelForPy3(x) 
#endif


SWIGINTERN PyObject*
SWIG_Python_str_FromChar(const char *c)
{
#if PY_VERSION_HEX >= 0x03000000
  return PyUnicode_FromString(c); 
#else
  return PyString_FromString(c);
#endif
}

/* Add PyOS_snprintf for old Pythons */
#if PY_VERSION_HEX < 0x02020000
# if defined(_MSC_VER) || defined(__BORLANDC__) || defined(_WATCOM)
#  define PyOS_snprintf _snprintf
# else
#  define PyOS_snprintf snprintf
# endif
#endif

/* A crude PyString_FromFormat implementation for old Pythons */
#if PY_VERSION_HEX < 0x02020000

#ifndef SWIG_PYBUFFER_SIZE
# define SWIG_PYBUFFER_SIZE 1024
#endif

static PyObject *
PyString_FromFormat(const char *fmt, ...) {
  va_list ap;
  char buf[SWIG_PYBUFFER_SIZE * 2];
  int res;
  va_start(ap, fmt);
  res = vsnprintf(buf, sizeof(buf), fmt, ap);
  va_end(ap);
  return (res < 0 || res >= (int)sizeof(buf)) ? 0 : PyString_FromString(buf);
}
#endif

/* Add PyObject_Del for old Pythons */
#if PY_VERSION_HEX < 0x01060000
# define PyObject_Del(op) PyMem_DEL((op))
#endif
#ifndef PyObject_DEL
# define PyObject_DEL PyObject_Del
#endif

/* A crude PyExc_StopIteration exception for old Pythons */
#if PY_VERSION_HEX < 0x02020000
# ifndef PyExc_StopIteration
#  define PyExc_StopIteration PyExc_RuntimeError
# endif
# ifndef PyObject_GenericGetAttr
#  define PyObject_GenericGetAttr 0
# endif
#endif

/* Py_NotImplemented is defined in 2.1 and up. */
#if PY_VERSION_HEX < 0x02010000
# ifndef Py_NotImplemented
#  define Py_NotImplemented PyExc_RuntimeError
# endif
#endif

/* A crude PyString_AsStringAndSize implementation for old Pythons */
#if PY_VERSION_HEX < 0x02010000
# ifndef PyString_AsStringAndSize
#  define PyString_AsStringAndSize(obj, s, len) {*s = PyString_AsString(obj); *len = *s ? strlen(*s) : 0;}
# endif
#endif

/* PySequence_Size for old Pythons */
#if PY_VERSION_HEX < 0x02000000
# ifndef PySequence_Size
#  define PySequence_Size PySequence_Length
# endif
#endif

/* PyBool_FromLong for old Pythons */
#if PY_VERSION_HEX < 0x02030000
static
PyObject *PyBool_FromLong(long ok)
{
  PyObject *result = ok ? Py_True : Py_False;
  Py_INCREF(result);
  return result;
}
#endif

/* Py_ssize_t for old Pythons */
/* This code is as recommended by: */
/* http://www.python.org/dev/peps/pep-0353/#conversion-guidelines */
#if PY_VERSION_HEX < 0x02050000 && !defined(PY_SSIZE_T_MIN)
typedef int Py_ssize_t;
# define PY_SSIZE_T_MAX INT_MAX
# define PY_SSIZE_T_MIN INT_MIN
typedef inquiry lenfunc;
typedef intargfunc ssizeargfunc;
typedef intintargfunc ssizessizeargfunc;
typedef intobjargproc ssizeobjargproc;
typedef intintobjargproc ssizessizeobjargproc;
typedef getreadbufferproc readbufferproc;
typedef getwritebufferproc writebufferproc;
typedef getsegcountproc segcountproc;
typedef getcharbufferproc charbufferproc;
static long PyNumber_AsSsize_t (PyObject *x, void *SWIGUNUSEDPARM(exc))
{
  long result = 0;
  PyObject *i = PyNumber_Int(x);
  if (i) {
    result = PyInt_AsLong(i);
    Py_DECREF(i);
  }
  return result;
}
#endif

#if PY_VERSION_HEX < 0x02050000
#define PyInt_FromSize_t(x) PyInt_FromLong((long)x)
#endif

#if PY_VERSION_HEX < 0x02040000
#define Py_VISIT(op)				\
  do { 						\
    if (op) {					\
      int vret = visit((op), arg);		\
      if (vret)					\
        return vret;				\
    }						\
  } while (0)
#endif

#if PY_VERSION_HEX < 0x02030000
typedef struct {
  PyTypeObject type;
  PyNumberMethods as_number;
  PyMappingMethods as_mapping;
  PySequenceMethods as_sequence;
  PyBufferProcs as_buffer;
  PyObject *name, *slots;
} PyHeapTypeObject;
#endif

#if PY_VERSION_HEX < 0x02030000
typedef destructor freefunc;
#endif

#if ((PY_MAJOR_VERSION == 2 && PY_MINOR_VERSION > 6) || \
     (PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION > 0) || \
     (PY_MAJOR_VERSION > 3))
# define SWIGPY_USE_CAPSULE
# define SWIGPY_CAPSULE_NAME ((char*)"swig_runtime_data" SWIG_RUNTIME_VERSION ".type_pointer_capsule" SWIG_TYPE_TABLE_NAME)
#endif

#if PY_VERSION_HEX < 0x03020000
#define PyDescr_TYPE(x) (((PyDescrObject *)(x))->d_type)
#define PyDescr_NAME(x) (((PyDescrObject *)(x))->d_name)
#endif

/* -----------------------------------------------------------------------------
 * error manipulation
 * ----------------------------------------------------------------------------- */

SWIGRUNTIME PyObject*
SWIG_Python_ErrorType(int code) {
  PyObject* type = 0;
  switch(code) {
  case SWIG_MemoryError:
    type = PyExc_MemoryError;
    break;
  case SWIG_IOError:
    type = PyExc_IOError;
    break;
  case SWIG_RuntimeError:
    type = PyExc_RuntimeError;
    break;
  case SWIG_IndexError:
    type = PyExc_IndexError;
    break;
  case SWIG_TypeError:
    type = PyExc_TypeError;
    break;
  case SWIG_DivisionByZero:
    type = PyExc_ZeroDivisionError;
    break;
  case SWIG_OverflowError:
    type = PyExc_OverflowError;
    break;
  case SWIG_SyntaxError:
    type = PyExc_SyntaxError;
    break;
  case SWIG_ValueError:
    type = PyExc_ValueError;
    break;
  case SWIG_SystemError:
    type = PyExc_SystemError;
    break;
  case SWIG_AttributeError:
    type = PyExc_AttributeError;
    break;
  default:
    type = PyExc_RuntimeError;
  }
  return type;
}


SWIGRUNTIME void
SWIG_Python_AddErrorMsg(const char* mesg)
{
  PyObject *type = 0;
  PyObject *value = 0;
  PyObject *traceback = 0;

  if (PyErr_Occurred()) PyErr_Fetch(&type, &value, &traceback);
  if (value) {
    char *tmp;
    PyObject *old_str = PyObject_Str(value);
    PyErr_Clear();
    Py_XINCREF(type);

    PyErr_Format(type, "%s %s", tmp = SWIG_Python_str_AsChar(old_str), mesg);
    SWIG_Python_str_DelForPy3(tmp);
    Py_DECREF(old_str);
    Py_DECREF(value);
  } else {
    PyErr_SetString(PyExc_RuntimeError, mesg);
  }
}

#if defined(SWIG_PYTHON_NO_THREADS)
#  if defined(SWIG_PYTHON_THREADS)
#    undef SWIG_PYTHON_THREADS
#  endif
#endif
#if defined(SWIG_PYTHON_THREADS) /* Threading support is enabled */
#  if !defined(SWIG_PYTHON_USE_GIL) && !defined(SWIG_PYTHON_NO_USE_GIL)
#    if (PY_VERSION_HEX >= 0x02030000) /* For 2.3 or later, use the PyGILState calls */
#      define SWIG_PYTHON_USE_GIL
#    endif
#  endif
#  if defined(SWIG_PYTHON_USE_GIL) /* Use PyGILState threads calls */
#    ifndef SWIG_PYTHON_INITIALIZE_THREADS
#     define SWIG_PYTHON_INITIALIZE_THREADS  PyEval_InitThreads() 
#    endif
#    ifdef __cplusplus /* C++ code */
       class SWIG_Python_Thread_Block {
         bool status;
         PyGILState_STATE state;
       public:
         void end() { if (status) { PyGILState_Release(state); status = false;} }
         SWIG_Python_Thread_Block() : status(true), state(PyGILState_Ensure()) {}
         ~SWIG_Python_Thread_Block() { end(); }
       };
       class SWIG_Python_Thread_Allow {
         bool status;
         PyThreadState *save;
       public:
         void end() { if (status) { PyEval_RestoreThread(save); status = false; }}
         SWIG_Python_Thread_Allow() : status(true), save(PyEval_SaveThread()) {}
         ~SWIG_Python_Thread_Allow() { end(); }
       };
#      define SWIG_PYTHON_THREAD_BEGIN_BLOCK   SWIG_Python_Thread_Block _swig_thread_block
#      define SWIG_PYTHON_THREAD_END_BLOCK     _swig_thread_block.end()
#      define SWIG_PYTHON_THREAD_BEGIN_ALLOW   SWIG_Python_Thread_Allow _swig_thread_allow
#      define SWIG_PYTHON_THREAD_END_ALLOW     _swig_thread_allow.end()
#    else /* C code */
#      define SWIG_PYTHON_THREAD_BEGIN_BLOCK   PyGILState_STATE _swig_thread_block = PyGILState_Ensure()
#      define SWIG_PYTHON_THREAD_END_BLOCK     PyGILState_Release(_swig_thread_block)
#      define SWIG_PYTHON_THREAD_BEGIN_ALLOW   PyThreadState *_swig_thread_allow = PyEval_SaveThread()
#      define SWIG_PYTHON_THREAD_END_ALLOW     PyEval_RestoreThread(_swig_thread_allow)
#    endif
#  else /* Old thread way, not implemented, user must provide it */
#    if !defined(SWIG_PYTHON_INITIALIZE_THREADS)
#      define SWIG_PYTHON_INITIALIZE_THREADS
#    endif
#    if !defined(SWIG_PYTHON_THREAD_BEGIN_BLOCK)
#      define SWIG_PYTHON_THREAD_BEGIN_BLOCK
#    endif
#    if !defined(SWIG_PYTHON_THREAD_END_BLOCK)
#      define SWIG_PYTHON_THREAD_END_BLOCK
#    endif
#    if !defined(SWIG_PYTHON_THREAD_BEGIN_ALLOW)
#      define SWIG_PYTHON_THREAD_BEGIN_ALLOW
#    endif
#    if !defined(SWIG_PYTHON_THREAD_END_ALLOW)
#      define SWIG_PYTHON_THREAD_END_ALLOW
#    endif
#  endif
#else /* No thread support */
#  define SWIG_PYTHON_INITIALIZE_THREADS
#  define SWIG_PYTHON_THREAD_BEGIN_BLOCK
#  define SWIG_PYTHON_THREAD_END_BLOCK
#  define SWIG_PYTHON_THREAD_BEGIN_ALLOW
#  define SWIG_PYTHON_THREAD_END_ALLOW
#endif

/* -----------------------------------------------------------------------------
 * Python API portion that goes into the runtime
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#endif

/* -----------------------------------------------------------------------------
 * Constant declarations
 * ----------------------------------------------------------------------------- */

/* Constant Types */
#define SWIG_PY_POINTER 4
#define SWIG_PY_BINARY  5

/* Constant information structure */
typedef struct swig_const_info {
  int type;
  char *name;
  long lvalue;
  double dvalue;
  void   *pvalue;
  swig_type_info **ptype;
} swig_const_info;


/* -----------------------------------------------------------------------------
 * Wrapper of PyInstanceMethod_New() used in Python 3
 * It is exported to the generated module, used for -fastproxy
 * ----------------------------------------------------------------------------- */
#if PY_VERSION_HEX >= 0x03000000
SWIGRUNTIME PyObject* SWIG_PyInstanceMethod_New(PyObject *SWIGUNUSEDPARM(self), PyObject *func)
{
  return PyInstanceMethod_New(func);
}
#else
SWIGRUNTIME PyObject* SWIG_PyInstanceMethod_New(PyObject *SWIGUNUSEDPARM(self), PyObject *SWIGUNUSEDPARM(func))
{
  return NULL;
}
#endif

#ifdef __cplusplus
}
#endif


/* -----------------------------------------------------------------------------
 * pyrun.swg
 *
 * This file contains the runtime support for Python modules
 * and includes code for managing global variables and pointer
 * type checking.
 *
 * ----------------------------------------------------------------------------- */

/* Common SWIG API */

/* for raw pointers */
#define SWIG_Python_ConvertPtr(obj, pptr, type, flags)  SWIG_Python_ConvertPtrAndOwn(obj, pptr, type, flags, 0)
#define SWIG_ConvertPtr(obj, pptr, type, flags)         SWIG_Python_ConvertPtr(obj, pptr, type, flags)
#define SWIG_ConvertPtrAndOwn(obj,pptr,type,flags,own)  SWIG_Python_ConvertPtrAndOwn(obj, pptr, type, flags, own)

#ifdef SWIGPYTHON_BUILTIN
#define SWIG_NewPointerObj(ptr, type, flags)            SWIG_Python_NewPointerObj(self, ptr, type, flags)
#else
#define SWIG_NewPointerObj(ptr, type, flags)            SWIG_Python_NewPointerObj(NULL, ptr, type, flags)
#endif

#define SWIG_InternalNewPointerObj(ptr, type, flags)	SWIG_Python_NewPointerObj(NULL, ptr, type, flags)

#define SWIG_CheckImplicit(ty)                          SWIG_Python_CheckImplicit(ty) 
#define SWIG_AcquirePtr(ptr, src)                       SWIG_Python_AcquirePtr(ptr, src)
#define swig_owntype                                    int

/* for raw packed data */
#define SWIG_ConvertPacked(obj, ptr, sz, ty)            SWIG_Python_ConvertPacked(obj, ptr, sz, ty)
#define SWIG_NewPackedObj(ptr, sz, type)                SWIG_Python_NewPackedObj(ptr, sz, type)

/* for class or struct pointers */
#define SWIG_ConvertInstance(obj, pptr, type, flags)    SWIG_ConvertPtr(obj, pptr, type, flags)
#define SWIG_NewInstanceObj(ptr, type, flags)           SWIG_NewPointerObj(ptr, type, flags)

/* for C or C++ function pointers */
#define SWIG_ConvertFunctionPtr(obj, pptr, type)        SWIG_Python_ConvertFunctionPtr(obj, pptr, type)
#define SWIG_NewFunctionPtrObj(ptr, type)               SWIG_Python_NewPointerObj(NULL, ptr, type, 0)

/* for C++ member pointers, ie, member methods */
#define SWIG_ConvertMember(obj, ptr, sz, ty)            SWIG_Python_ConvertPacked(obj, ptr, sz, ty)
#define SWIG_NewMemberObj(ptr, sz, type)                SWIG_Python_NewPackedObj(ptr, sz, type)


/* Runtime API */

#define SWIG_GetModule(clientdata)                      SWIG_Python_GetModule(clientdata)
#define SWIG_SetModule(clientdata, pointer)             SWIG_Python_SetModule(pointer)
#define SWIG_NewClientData(obj)                         SwigPyClientData_New(obj)

#define SWIG_SetErrorObj                                SWIG_Python_SetErrorObj                            
#define SWIG_SetErrorMsg                        	SWIG_Python_SetErrorMsg				   
#define SWIG_ErrorType(code)                    	SWIG_Python_ErrorType(code)                        
#define SWIG_Error(code, msg)            		SWIG_Python_SetErrorMsg(SWIG_ErrorType(code), msg) 
#define SWIG_fail                        		goto fail					   


/* Runtime API implementation */

/* Error manipulation */

SWIGINTERN void 
SWIG_Python_SetErrorObj(PyObject *errtype, PyObject *obj) {
  SWIG_PYTHON_THREAD_BEGIN_BLOCK; 
  PyErr_SetObject(errtype, obj);
  Py_DECREF(obj);
  SWIG_PYTHON_THREAD_END_BLOCK;
}

SWIGINTERN void 
SWIG_Python_SetErrorMsg(PyObject *errtype, const char *msg) {
  SWIG_PYTHON_THREAD_BEGIN_BLOCK;
  PyErr_SetString(errtype, msg);
  SWIG_PYTHON_THREAD_END_BLOCK;
}

#define SWIG_Python_Raise(obj, type, desc)  SWIG_Python_SetErrorObj(SWIG_Python_ExceptionType(desc), obj)

/* Set a constant value */

#if defined(SWIGPYTHON_BUILTIN)

SWIGINTERN void
SwigPyBuiltin_AddPublicSymbol(PyObject *seq, const char *key) {
  PyObject *s = PyString_InternFromString(key);
  PyList_Append(seq, s);
  Py_DECREF(s);
}

SWIGINTERN void
SWIG_Python_SetConstant(PyObject *d, PyObject *public_interface, const char *name, PyObject *obj) {   
#if PY_VERSION_HEX < 0x02030000
  PyDict_SetItemString(d, (char *)name, obj);
#else
  PyDict_SetItemString(d, name, obj);
#endif
  Py_DECREF(obj);
  if (public_interface)
    SwigPyBuiltin_AddPublicSymbol(public_interface, name);
}

#else

SWIGINTERN void
SWIG_Python_SetConstant(PyObject *d, const char *name, PyObject *obj) {   
#if PY_VERSION_HEX < 0x02030000
  PyDict_SetItemString(d, (char *)name, obj);
#else
  PyDict_SetItemString(d, name, obj);
#endif
  Py_DECREF(obj);                            
}

#endif

/* Append a value to the result obj */

SWIGINTERN PyObject*
SWIG_Python_AppendOutput(PyObject* result, PyObject* obj) {
#if !defined(SWIG_PYTHON_OUTPUT_TUPLE)
  if (!result) {
    result = obj;
  } else if (result == Py_None) {
    Py_DECREF(result);
    result = obj;
  } else {
    if (!PyList_Check(result)) {
      PyObject *o2 = result;
      result = PyList_New(1);
      PyList_SetItem(result, 0, o2);
    }
    PyList_Append(result,obj);
    Py_DECREF(obj);
  }
  return result;
#else
  PyObject*   o2;
  PyObject*   o3;
  if (!result) {
    result = obj;
  } else if (result == Py_None) {
    Py_DECREF(result);
    result = obj;
  } else {
    if (!PyTuple_Check(result)) {
      o2 = result;
      result = PyTuple_New(1);
      PyTuple_SET_ITEM(result, 0, o2);
    }
    o3 = PyTuple_New(1);
    PyTuple_SET_ITEM(o3, 0, obj);
    o2 = result;
    result = PySequence_Concat(o2, o3);
    Py_DECREF(o2);
    Py_DECREF(o3);
  }
  return result;
#endif
}

/* Unpack the argument tuple */

SWIGINTERN int
SWIG_Python_UnpackTuple(PyObject *args, const char *name, Py_ssize_t min, Py_ssize_t max, PyObject **objs)
{
  if (!args) {
    if (!min && !max) {
      return 1;
    } else {
      PyErr_Format(PyExc_TypeError, "%s expected %s%d arguments, got none", 
		   name, (min == max ? "" : "at least "), (int)min);
      return 0;
    }
  }  
  if (!PyTuple_Check(args)) {
    if (min <= 1 && max >= 1) {
      int i;
      objs[0] = args;
      for (i = 1; i < max; ++i) {
	objs[i] = 0;
      }
      return 2;
    }
    PyErr_SetString(PyExc_SystemError, "UnpackTuple() argument list is not a tuple");
    return 0;
  } else {
    Py_ssize_t l = PyTuple_GET_SIZE(args);
    if (l < min) {
      PyErr_Format(PyExc_TypeError, "%s expected %s%d arguments, got %d", 
		   name, (min == max ? "" : "at least "), (int)min, (int)l);
      return 0;
    } else if (l > max) {
      PyErr_Format(PyExc_TypeError, "%s expected %s%d arguments, got %d", 
		   name, (min == max ? "" : "at most "), (int)max, (int)l);
      return 0;
    } else {
      int i;
      for (i = 0; i < l; ++i) {
	objs[i] = PyTuple_GET_ITEM(args, i);
      }
      for (; l < max; ++l) {
	objs[l] = 0;
      }
      return i + 1;
    }    
  }
}

/* A functor is a function object with one single object argument */
#if PY_VERSION_HEX >= 0x02020000
#define SWIG_Python_CallFunctor(functor, obj)	        PyObject_CallFunctionObjArgs(functor, obj, NULL);
#else
#define SWIG_Python_CallFunctor(functor, obj)	        PyObject_CallFunction(functor, "O", obj);
#endif

/*
  Helper for static pointer initialization for both C and C++ code, for example
  static PyObject *SWIG_STATIC_POINTER(MyVar) = NewSomething(...);
*/
#ifdef __cplusplus
#define SWIG_STATIC_POINTER(var)  var
#else
#define SWIG_STATIC_POINTER(var)  var = 0; if (!var) var
#endif

/* -----------------------------------------------------------------------------
 * Pointer declarations
 * ----------------------------------------------------------------------------- */

/* Flags for new pointer objects */
#define SWIG_POINTER_NOSHADOW       (SWIG_POINTER_OWN      << 1)
#define SWIG_POINTER_NEW            (SWIG_POINTER_NOSHADOW | SWIG_POINTER_OWN)

#define SWIG_POINTER_IMPLICIT_CONV  (SWIG_POINTER_DISOWN   << 1)

#define SWIG_BUILTIN_TP_INIT	    (SWIG_POINTER_OWN << 2)
#define SWIG_BUILTIN_INIT	    (SWIG_BUILTIN_TP_INIT | SWIG_POINTER_OWN)

#ifdef __cplusplus
extern "C" {
#endif

/*  How to access Py_None */
#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#  ifndef SWIG_PYTHON_NO_BUILD_NONE
#    ifndef SWIG_PYTHON_BUILD_NONE
#      define SWIG_PYTHON_BUILD_NONE
#    endif
#  endif
#endif

#ifdef SWIG_PYTHON_BUILD_NONE
#  ifdef Py_None
#   undef Py_None
#   define Py_None SWIG_Py_None()
#  endif
SWIGRUNTIMEINLINE PyObject * 
_SWIG_Py_None(void)
{
  PyObject *none = Py_BuildValue((char*)"");
  Py_DECREF(none);
  return none;
}
SWIGRUNTIME PyObject * 
SWIG_Py_None(void)
{
  static PyObject *SWIG_STATIC_POINTER(none) = _SWIG_Py_None();
  return none;
}
#endif

/* The python void return value */

SWIGRUNTIMEINLINE PyObject * 
SWIG_Py_Void(void)
{
  PyObject *none = Py_None;
  Py_INCREF(none);
  return none;
}

/* SwigPyClientData */

typedef struct {
  PyObject *klass;
  PyObject *newraw;
  PyObject *newargs;
  PyObject *destroy;
  int delargs;
  int implicitconv;
  PyTypeObject *pytype;
} SwigPyClientData;

SWIGRUNTIMEINLINE int 
SWIG_Python_CheckImplicit(swig_type_info *ty)
{
  SwigPyClientData *data = (SwigPyClientData *)ty->clientdata;
  return data ? data->implicitconv : 0;
}

SWIGRUNTIMEINLINE PyObject *
SWIG_Python_ExceptionType(swig_type_info *desc) {
  SwigPyClientData *data = desc ? (SwigPyClientData *) desc->clientdata : 0;
  PyObject *klass = data ? data->klass : 0;
  return (klass ? klass : PyExc_RuntimeError);
}


SWIGRUNTIME SwigPyClientData * 
SwigPyClientData_New(PyObject* obj)
{
  if (!obj) {
    return 0;
  } else {
    SwigPyClientData *data = (SwigPyClientData *)malloc(sizeof(SwigPyClientData));
    if (!data) {
        return 0;
    }
    /* the klass element */
    data->klass = obj;
    Py_INCREF(data->klass);
    /* the newraw method and newargs arguments used to create a new raw instance */
    if (PyClass_Check(obj)) {
      data->newraw = 0;
      data->newargs = obj;
      Py_INCREF(obj);
    } else {
#if (PY_VERSION_HEX < 0x02020000)
      data->newraw = 0;
#else
      data->newraw = PyObject_GetAttrString(data->klass, (char *)"__new__");
#endif
      if (data->newraw) {
	Py_INCREF(data->newraw);
	data->newargs = PyTuple_New(1);
	PyTuple_SetItem(data->newargs, 0, obj);
      } else {
	data->newargs = obj;
      }
      Py_INCREF(data->newargs);
    }
    /* the destroy method, aka as the C++ delete method */
    data->destroy = PyObject_GetAttrString(data->klass, (char *)"__swig_destroy__");
    if (PyErr_Occurred()) {
      PyErr_Clear();
      data->destroy = 0;
    }
    if (data->destroy) {
      int flags;
      Py_INCREF(data->destroy);
      flags = PyCFunction_GET_FLAGS(data->destroy);
#ifdef METH_O
      data->delargs = !(flags & (METH_O));
#else
      data->delargs = 0;
#endif
    } else {
      data->delargs = 0;
    }
    data->implicitconv = 0;
    data->pytype = 0;
    return data;
  }
}

SWIGRUNTIME void 
SwigPyClientData_Del(SwigPyClientData *data) {
  Py_XDECREF(data->newraw);
  Py_XDECREF(data->newargs);
  Py_XDECREF(data->destroy);
}

/* =============== SwigPyObject =====================*/

typedef struct {
  PyObject_HEAD
  void *ptr;
  swig_type_info *ty;
  int own;
  PyObject *next;
#ifdef SWIGPYTHON_BUILTIN
  PyObject *dict;
#endif
} SwigPyObject;

SWIGRUNTIME PyObject *
SwigPyObject_long(SwigPyObject *v)
{
  return PyLong_FromVoidPtr(v->ptr);
}

SWIGRUNTIME PyObject *
SwigPyObject_format(const char* fmt, SwigPyObject *v)
{
  PyObject *res = NULL;
  PyObject *args = PyTuple_New(1);
  if (args) {
    if (PyTuple_SetItem(args, 0, SwigPyObject_long(v)) == 0) {
      PyObject *ofmt = SWIG_Python_str_FromChar(fmt);
      if (ofmt) {
#if PY_VERSION_HEX >= 0x03000000
	res = PyUnicode_Format(ofmt,args);
#else
	res = PyString_Format(ofmt,args);
#endif
	Py_DECREF(ofmt);
      }
      Py_DECREF(args);
    }
  }
  return res;
}

SWIGRUNTIME PyObject *
SwigPyObject_oct(SwigPyObject *v)
{
  return SwigPyObject_format("%o",v);
}

SWIGRUNTIME PyObject *
SwigPyObject_hex(SwigPyObject *v)
{
  return SwigPyObject_format("%x",v);
}

SWIGRUNTIME PyObject *
#ifdef METH_NOARGS
SwigPyObject_repr(SwigPyObject *v)
#else
SwigPyObject_repr(SwigPyObject *v, PyObject *args)
#endif
{
  const char *name = SWIG_TypePrettyName(v->ty);
  PyObject *repr = SWIG_Python_str_FromFormat("<Swig Object of type '%s' at %p>", (name ? name : "unknown"), (void *)v);
  if (v->next) {
# ifdef METH_NOARGS
    PyObject *nrep = SwigPyObject_repr((SwigPyObject *)v->next);
# else
    PyObject *nrep = SwigPyObject_repr((SwigPyObject *)v->next, args);
# endif
# if PY_VERSION_HEX >= 0x03000000
    PyObject *joined = PyUnicode_Concat(repr, nrep);
    Py_DecRef(repr);
    Py_DecRef(nrep);
    repr = joined;
# else
    PyString_ConcatAndDel(&repr,nrep);
# endif
  }
  return repr;  
}

SWIGRUNTIME int
SwigPyObject_compare(SwigPyObject *v, SwigPyObject *w)
{
  void *i = v->ptr;
  void *j = w->ptr;
  return (i < j) ? -1 : ((i > j) ? 1 : 0);
}

/* Added for Python 3.x, would it also be useful for Python 2.x? */
SWIGRUNTIME PyObject*
SwigPyObject_richcompare(SwigPyObject *v, SwigPyObject *w, int op)
{
  PyObject* res;
  if( op != Py_EQ && op != Py_NE ) {
    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
  }
  res = PyBool_FromLong( (SwigPyObject_compare(v, w)==0) == (op == Py_EQ) ? 1 : 0);
  return res;  
}


SWIGRUNTIME PyTypeObject* SwigPyObject_TypeOnce(void);

#ifdef SWIGPYTHON_BUILTIN
static swig_type_info *SwigPyObject_stype = 0;
SWIGRUNTIME PyTypeObject*
SwigPyObject_type(void) {
    SwigPyClientData *cd;
    assert(SwigPyObject_stype);
    cd = (SwigPyClientData*) SwigPyObject_stype->clientdata;
    assert(cd);
    assert(cd->pytype);
    return cd->pytype;
}
#else
SWIGRUNTIME PyTypeObject*
SwigPyObject_type(void) {
  static PyTypeObject *SWIG_STATIC_POINTER(type) = SwigPyObject_TypeOnce();
  return type;
}
#endif

SWIGRUNTIMEINLINE int
SwigPyObject_Check(PyObject *op) {
#ifdef SWIGPYTHON_BUILTIN
  PyTypeObject *target_tp = SwigPyObject_type();
  if (PyType_IsSubtype(op->ob_type, target_tp))
    return 1;
  return (strcmp(op->ob_type->tp_name, "SwigPyObject") == 0);
#else
  return (Py_TYPE(op) == SwigPyObject_type())
    || (strcmp(Py_TYPE(op)->tp_name,"SwigPyObject") == 0);
#endif
}

SWIGRUNTIME PyObject *
SwigPyObject_New(void *ptr, swig_type_info *ty, int own);

SWIGRUNTIME void
SwigPyObject_dealloc(PyObject *v)
{
  SwigPyObject *sobj = (SwigPyObject *) v;
  PyObject *next = sobj->next;
  if (sobj->own == SWIG_POINTER_OWN) {
    swig_type_info *ty = sobj->ty;
    SwigPyClientData *data = ty ? (SwigPyClientData *) ty->clientdata : 0;
    PyObject *destroy = data ? data->destroy : 0;
    if (destroy) {
      /* destroy is always a VARARGS method */
      PyObject *res;
      if (data->delargs) {
	/* we need to create a temporary object to carry the destroy operation */
	PyObject *tmp = SwigPyObject_New(sobj->ptr, ty, 0);
	res = SWIG_Python_CallFunctor(destroy, tmp);
	Py_DECREF(tmp);
      } else {
	PyCFunction meth = PyCFunction_GET_FUNCTION(destroy);
	PyObject *mself = PyCFunction_GET_SELF(destroy);
	res = ((*meth)(mself, v));
      }
      Py_XDECREF(res);
    } 
#if !defined(SWIG_PYTHON_SILENT_MEMLEAK)
    else {
      const char *name = SWIG_TypePrettyName(ty);
      printf("swig/python detected a memory leak of type '%s', no destructor found.\n", (name ? name : "unknown"));
    }
#endif
  } 
  Py_XDECREF(next);
  PyObject_DEL(v);
}

SWIGRUNTIME PyObject* 
SwigPyObject_append(PyObject* v, PyObject* next)
{
  SwigPyObject *sobj = (SwigPyObject *) v;
#ifndef METH_O
  PyObject *tmp = 0;
  if (!PyArg_ParseTuple(next,(char *)"O:append", &tmp)) return NULL;
  next = tmp;
#endif
  if (!SwigPyObject_Check(next)) {
    return NULL;
  }
  sobj->next = next;
  Py_INCREF(next);
  return SWIG_Py_Void();
}

SWIGRUNTIME PyObject* 
#ifdef METH_NOARGS
SwigPyObject_next(PyObject* v)
#else
SwigPyObject_next(PyObject* v, PyObject *SWIGUNUSEDPARM(args))
#endif
{
  SwigPyObject *sobj = (SwigPyObject *) v;
  if (sobj->next) {    
    Py_INCREF(sobj->next);
    return sobj->next;
  } else {
    return SWIG_Py_Void();
  }
}

SWIGINTERN PyObject*
#ifdef METH_NOARGS
SwigPyObject_disown(PyObject *v)
#else
SwigPyObject_disown(PyObject* v, PyObject *SWIGUNUSEDPARM(args))
#endif
{
  SwigPyObject *sobj = (SwigPyObject *)v;
  sobj->own = 0;
  return SWIG_Py_Void();
}

SWIGINTERN PyObject*
#ifdef METH_NOARGS
SwigPyObject_acquire(PyObject *v)
#else
SwigPyObject_acquire(PyObject* v, PyObject *SWIGUNUSEDPARM(args))
#endif
{
  SwigPyObject *sobj = (SwigPyObject *)v;
  sobj->own = SWIG_POINTER_OWN;
  return SWIG_Py_Void();
}

SWIGINTERN PyObject*
SwigPyObject_own(PyObject *v, PyObject *args)
{
  PyObject *val = 0;
#if (PY_VERSION_HEX < 0x02020000)
  if (!PyArg_ParseTuple(args,(char *)"|O:own",&val))
#elif (PY_VERSION_HEX < 0x02050000)
  if (!PyArg_UnpackTuple(args, (char *)"own", 0, 1, &val)) 
#else
  if (!PyArg_UnpackTuple(args, "own", 0, 1, &val)) 
#endif
    {
      return NULL;
    } 
  else
    {
      SwigPyObject *sobj = (SwigPyObject *)v;
      PyObject *obj = PyBool_FromLong(sobj->own);
      if (val) {
#ifdef METH_NOARGS
	if (PyObject_IsTrue(val)) {
	  SwigPyObject_acquire(v);
	} else {
	  SwigPyObject_disown(v);
	}
#else
	if (PyObject_IsTrue(val)) {
	  SwigPyObject_acquire(v,args);
	} else {
	  SwigPyObject_disown(v,args);
	}
#endif
      } 
      return obj;
    }
}

#ifdef METH_O
static PyMethodDef
swigobject_methods[] = {
  {(char *)"disown",  (PyCFunction)SwigPyObject_disown,  METH_NOARGS,  (char *)"releases ownership of the pointer"},
  {(char *)"acquire", (PyCFunction)SwigPyObject_acquire, METH_NOARGS,  (char *)"acquires ownership of the pointer"},
  {(char *)"own",     (PyCFunction)SwigPyObject_own,     METH_VARARGS, (char *)"returns/sets ownership of the pointer"},
  {(char *)"append",  (PyCFunction)SwigPyObject_append,  METH_O,       (char *)"appends another 'this' object"},
  {(char *)"next",    (PyCFunction)SwigPyObject_next,    METH_NOARGS,  (char *)"returns the next 'this' object"},
  {(char *)"__repr__",(PyCFunction)SwigPyObject_repr,    METH_NOARGS,  (char *)"returns object representation"},
  {0, 0, 0, 0}  
};
#else
static PyMethodDef
swigobject_methods[] = {
  {(char *)"disown",  (PyCFunction)SwigPyObject_disown,  METH_VARARGS,  (char *)"releases ownership of the pointer"},
  {(char *)"acquire", (PyCFunction)SwigPyObject_acquire, METH_VARARGS,  (char *)"aquires ownership of the pointer"},
  {(char *)"own",     (PyCFunction)SwigPyObject_own,     METH_VARARGS,  (char *)"returns/sets ownership of the pointer"},
  {(char *)"append",  (PyCFunction)SwigPyObject_append,  METH_VARARGS,  (char *)"appends another 'this' object"},
  {(char *)"next",    (PyCFunction)SwigPyObject_next,    METH_VARARGS,  (char *)"returns the next 'this' object"},
  {(char *)"__repr__",(PyCFunction)SwigPyObject_repr,   METH_VARARGS,  (char *)"returns object representation"},
  {0, 0, 0, 0}  
};
#endif

#if PY_VERSION_HEX < 0x02020000
SWIGINTERN PyObject *
SwigPyObject_getattr(SwigPyObject *sobj,char *name)
{
  return Py_FindMethod(swigobject_methods, (PyObject *)sobj, name);
}
#endif

SWIGRUNTIME PyTypeObject*
SwigPyObject_TypeOnce(void) {
  static char swigobject_doc[] = "Swig object carries a C/C++ instance pointer";

  static PyNumberMethods SwigPyObject_as_number = {
    (binaryfunc)0, /*nb_add*/
    (binaryfunc)0, /*nb_subtract*/
    (binaryfunc)0, /*nb_multiply*/
    /* nb_divide removed in Python 3 */
#if PY_VERSION_HEX < 0x03000000
    (binaryfunc)0, /*nb_divide*/
#endif
    (binaryfunc)0, /*nb_remainder*/
    (binaryfunc)0, /*nb_divmod*/
    (ternaryfunc)0,/*nb_power*/
    (unaryfunc)0,  /*nb_negative*/
    (unaryfunc)0,  /*nb_positive*/
    (unaryfunc)0,  /*nb_absolute*/
    (inquiry)0,    /*nb_nonzero*/
    0,		   /*nb_invert*/
    0,		   /*nb_lshift*/
    0,		   /*nb_rshift*/
    0,		   /*nb_and*/
    0,		   /*nb_xor*/
    0,		   /*nb_or*/
#if PY_VERSION_HEX < 0x03000000
    0,   /*nb_coerce*/
#endif
    (unaryfunc)SwigPyObject_long, /*nb_int*/
#if PY_VERSION_HEX < 0x03000000
    (unaryfunc)SwigPyObject_long, /*nb_long*/
#else
    0, /*nb_reserved*/
#endif
    (unaryfunc)0,                 /*nb_float*/
#if PY_VERSION_HEX < 0x03000000
    (unaryfunc)SwigPyObject_oct,  /*nb_oct*/
    (unaryfunc)SwigPyObject_hex,  /*nb_hex*/
#endif
#if PY_VERSION_HEX >= 0x03000000 /* 3.0 */
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_index, nb_inplace_divide removed */
#elif PY_VERSION_HEX >= 0x02050000 /* 2.5.0 */
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_index */
#elif PY_VERSION_HEX >= 0x02020000 /* 2.2.0 */
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_inplace_true_divide */
#elif PY_VERSION_HEX >= 0x02000000 /* 2.0.0 */
    0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_inplace_or */
#endif
  };

  static PyTypeObject swigpyobject_type;
  static int type_init = 0;
  if (!type_init) {
    const PyTypeObject tmp = {
      /* PyObject header changed in Python 3 */
#if PY_VERSION_HEX >= 0x03000000
      PyVarObject_HEAD_INIT(NULL, 0)
#else
      PyObject_HEAD_INIT(NULL)
      0,                                    /* ob_size */
#endif
      (char *)"SwigPyObject",               /* tp_name */
      sizeof(SwigPyObject),                 /* tp_basicsize */
      0,                                    /* tp_itemsize */
      (destructor)SwigPyObject_dealloc,     /* tp_dealloc */
      0,				    /* tp_print */
#if PY_VERSION_HEX < 0x02020000
      (getattrfunc)SwigPyObject_getattr,    /* tp_getattr */
#else
      (getattrfunc)0,                       /* tp_getattr */
#endif
      (setattrfunc)0,                       /* tp_setattr */
#if PY_VERSION_HEX >= 0x03000000
    0, /* tp_reserved in 3.0.1, tp_compare in 3.0.0 but not used */
#else
      (cmpfunc)SwigPyObject_compare,        /* tp_compare */
#endif
      (reprfunc)SwigPyObject_repr,          /* tp_repr */
      &SwigPyObject_as_number,              /* tp_as_number */
      0,                                    /* tp_as_sequence */
      0,                                    /* tp_as_mapping */
      (hashfunc)0,                          /* tp_hash */
      (ternaryfunc)0,                       /* tp_call */
      0,				    /* tp_str */
      PyObject_GenericGetAttr,              /* tp_getattro */
      0,                                    /* tp_setattro */
      0,                                    /* tp_as_buffer */
      Py_TPFLAGS_DEFAULT,                   /* tp_flags */
      swigobject_doc,                       /* tp_doc */
      0,                                    /* tp_traverse */
      0,                                    /* tp_clear */
      (richcmpfunc)SwigPyObject_richcompare,/* tp_richcompare */
      0,                                    /* tp_weaklistoffset */
#if PY_VERSION_HEX >= 0x02020000
      0,                                    /* tp_iter */
      0,                                    /* tp_iternext */
      swigobject_methods,                   /* tp_methods */
      0,                                    /* tp_members */
      0,                                    /* tp_getset */
      0,                                    /* tp_base */
      0,                                    /* tp_dict */
      0,                                    /* tp_descr_get */
      0,                                    /* tp_descr_set */
      0,                                    /* tp_dictoffset */
      0,                                    /* tp_init */
      0,                                    /* tp_alloc */
      0,                                    /* tp_new */
      0,                                    /* tp_free */
      0,                                    /* tp_is_gc */
      0,                                    /* tp_bases */
      0,                                    /* tp_mro */
      0,                                    /* tp_cache */
      0,                                    /* tp_subclasses */
      0,                                    /* tp_weaklist */
#endif
#if PY_VERSION_HEX >= 0x02030000
      0,                                    /* tp_del */
#endif
#if PY_VERSION_HEX >= 0x02060000
      0,                                    /* tp_version */
#endif
#ifdef COUNT_ALLOCS
      0,0,0,0                               /* tp_alloc -> tp_next */
#endif
    };
    swigpyobject_type = tmp;
    type_init = 1;
#if PY_VERSION_HEX < 0x02020000
    swigpyobject_type.ob_type = &PyType_Type;
#else
    if (PyType_Ready(&swigpyobject_type) < 0)
      return NULL;
#endif
  }
  return &swigpyobject_type;
}

SWIGRUNTIME PyObject *
SwigPyObject_New(void *ptr, swig_type_info *ty, int own)
{
  SwigPyObject *sobj = PyObject_NEW(SwigPyObject, SwigPyObject_type());
  if (sobj) {
    sobj->ptr  = ptr;
    sobj->ty   = ty;
    sobj->own  = own;
    sobj->next = 0;
  }
  return (PyObject *)sobj;
}

/* -----------------------------------------------------------------------------
 * Implements a simple Swig Packed type, and use it instead of string
 * ----------------------------------------------------------------------------- */

typedef struct {
  PyObject_HEAD
  void *pack;
  swig_type_info *ty;
  size_t size;
} SwigPyPacked;

SWIGRUNTIME int
SwigPyPacked_print(SwigPyPacked *v, FILE *fp, int SWIGUNUSEDPARM(flags))
{
  char result[SWIG_BUFFER_SIZE];
  fputs("<Swig Packed ", fp); 
  if (SWIG_PackDataName(result, v->pack, v->size, 0, sizeof(result))) {
    fputs("at ", fp); 
    fputs(result, fp); 
  }
  fputs(v->ty->name,fp); 
  fputs(">", fp);
  return 0; 
}
  
SWIGRUNTIME PyObject *
SwigPyPacked_repr(SwigPyPacked *v)
{
  char result[SWIG_BUFFER_SIZE];
  if (SWIG_PackDataName(result, v->pack, v->size, 0, sizeof(result))) {
    return SWIG_Python_str_FromFormat("<Swig Packed at %s%s>", result, v->ty->name);
  } else {
    return SWIG_Python_str_FromFormat("<Swig Packed %s>", v->ty->name);
  }  
}

SWIGRUNTIME PyObject *
SwigPyPacked_str(SwigPyPacked *v)
{
  char result[SWIG_BUFFER_SIZE];
  if (SWIG_PackDataName(result, v->pack, v->size, 0, sizeof(result))){
    return SWIG_Python_str_FromFormat("%s%s", result, v->ty->name);
  } else {
    return SWIG_Python_str_FromChar(v->ty->name);
  }  
}

SWIGRUNTIME int
SwigPyPacked_compare(SwigPyPacked *v, SwigPyPacked *w)
{
  size_t i = v->size;
  size_t j = w->size;
  int s = (i < j) ? -1 : ((i > j) ? 1 : 0);
  return s ? s : strncmp((char *)v->pack, (char *)w->pack, 2*v->size);
}

SWIGRUNTIME PyTypeObject* SwigPyPacked_TypeOnce(void);

SWIGRUNTIME PyTypeObject*
SwigPyPacked_type(void) {
  static PyTypeObject *SWIG_STATIC_POINTER(type) = SwigPyPacked_TypeOnce();
  return type;
}

SWIGRUNTIMEINLINE int
SwigPyPacked_Check(PyObject *op) {
  return ((op)->ob_type == SwigPyPacked_TypeOnce()) 
    || (strcmp((op)->ob_type->tp_name,"SwigPyPacked") == 0);
}

SWIGRUNTIME void
SwigPyPacked_dealloc(PyObject *v)
{
  if (SwigPyPacked_Check(v)) {
    SwigPyPacked *sobj = (SwigPyPacked *) v;
    free(sobj->pack);
  }
  PyObject_DEL(v);
}

SWIGRUNTIME PyTypeObject*
SwigPyPacked_TypeOnce(void) {
  static char swigpacked_doc[] = "Swig object carries a C/C++ instance pointer";
  static PyTypeObject swigpypacked_type;
  static int type_init = 0;
  if (!type_init) {
    const PyTypeObject tmp = {
      /* PyObject header changed in Python 3 */
#if PY_VERSION_HEX>=0x03000000
      PyVarObject_HEAD_INIT(NULL, 0)
#else
      PyObject_HEAD_INIT(NULL)
      0,                                    /* ob_size */
#endif
      (char *)"SwigPyPacked",               /* tp_name */
      sizeof(SwigPyPacked),                 /* tp_basicsize */
      0,                                    /* tp_itemsize */
      (destructor)SwigPyPacked_dealloc,     /* tp_dealloc */
      (printfunc)SwigPyPacked_print,        /* tp_print */
      (getattrfunc)0,                       /* tp_getattr */
      (setattrfunc)0,                       /* tp_setattr */
#if PY_VERSION_HEX>=0x03000000
      0, /* tp_reserved in 3.0.1 */
#else
      (cmpfunc)SwigPyPacked_compare,        /* tp_compare */
#endif
      (reprfunc)SwigPyPacked_repr,          /* tp_repr */
      0,                                    /* tp_as_number */
      0,                                    /* tp_as_sequence */
      0,                                    /* tp_as_mapping */
      (hashfunc)0,                          /* tp_hash */
      (ternaryfunc)0,                       /* tp_call */
      (reprfunc)SwigPyPacked_str,           /* tp_str */
      PyObject_GenericGetAttr,              /* tp_getattro */
      0,                                    /* tp_setattro */
      0,                                    /* tp_as_buffer */
      Py_TPFLAGS_DEFAULT,                   /* tp_flags */
      swigpacked_doc,                       /* tp_doc */
      0,                                    /* tp_traverse */
      0,                                    /* tp_clear */
      0,                                    /* tp_richcompare */
      0,                                    /* tp_weaklistoffset */
#if PY_VERSION_HEX >= 0x02020000
      0,                                    /* tp_iter */
      0,                                    /* tp_iternext */
      0,                                    /* tp_methods */
      0,                                    /* tp_members */
      0,                                    /* tp_getset */
      0,                                    /* tp_base */
      0,                                    /* tp_dict */
      0,                                    /* tp_descr_get */
      0,                                    /* tp_descr_set */
      0,                                    /* tp_dictoffset */
      0,                                    /* tp_init */
      0,                                    /* tp_alloc */
      0,                                    /* tp_new */
      0,                                    /* tp_free */
      0,                                    /* tp_is_gc */
      0,                                    /* tp_bases */
      0,                                    /* tp_mro */
      0,                                    /* tp_cache */
      0,                                    /* tp_subclasses */
      0,                                    /* tp_weaklist */
#endif
#if PY_VERSION_HEX >= 0x02030000
      0,                                    /* tp_del */
#endif
#if PY_VERSION_HEX >= 0x02060000
      0,                                    /* tp_version */
#endif
#ifdef COUNT_ALLOCS
      0,0,0,0                               /* tp_alloc -> tp_next */
#endif
    };
    swigpypacked_type = tmp;
    type_init = 1;
#if PY_VERSION_HEX < 0x02020000
    swigpypacked_type.ob_type = &PyType_Type;
#else
    if (PyType_Ready(&swigpypacked_type) < 0)
      return NULL;
#endif
  }
  return &swigpypacked_type;
}

SWIGRUNTIME PyObject *
SwigPyPacked_New(void *ptr, size_t size, swig_type_info *ty)
{
  SwigPyPacked *sobj = PyObject_NEW(SwigPyPacked, SwigPyPacked_type());
  if (sobj) {
    void *pack = malloc(size);
    if (pack) {
      memcpy(pack, ptr, size);
      sobj->pack = pack;
      sobj->ty   = ty;
      sobj->size = size;
    } else {
      PyObject_DEL((PyObject *) sobj);
      sobj = 0;
    }
  }
  return (PyObject *) sobj;
}

SWIGRUNTIME swig_type_info *
SwigPyPacked_UnpackData(PyObject *obj, void *ptr, size_t size)
{
  if (SwigPyPacked_Check(obj)) {
    SwigPyPacked *sobj = (SwigPyPacked *)obj;
    if (sobj->size != size) return 0;
    memcpy(ptr, sobj->pack, size);
    return sobj->ty;
  } else {
    return 0;
  }
}

/* -----------------------------------------------------------------------------
 * pointers/data manipulation
 * ----------------------------------------------------------------------------- */

SWIGRUNTIMEINLINE PyObject *
_SWIG_This(void)
{
    return SWIG_Python_str_FromChar("this");
}

static PyObject *swig_this = NULL;

SWIGRUNTIME PyObject *
SWIG_This(void)
{
  if (swig_this == NULL)
    swig_this = _SWIG_This();
  return swig_this;
}

/* #define SWIG_PYTHON_SLOW_GETSET_THIS */

/* TODO: I don't know how to implement the fast getset in Python 3 right now */
#if PY_VERSION_HEX>=0x03000000
#define SWIG_PYTHON_SLOW_GETSET_THIS 
#endif

SWIGRUNTIME SwigPyObject *
SWIG_Python_GetSwigThis(PyObject *pyobj) 
{
  PyObject *obj;

  if (SwigPyObject_Check(pyobj))
    return (SwigPyObject *) pyobj;

#ifdef SWIGPYTHON_BUILTIN
  (void)obj;
# ifdef PyWeakref_CheckProxy
  if (PyWeakref_CheckProxy(pyobj)) {
    pyobj = PyWeakref_GET_OBJECT(pyobj);
    if (pyobj && SwigPyObject_Check(pyobj))
      return (SwigPyObject*) pyobj;
  }
# endif
  return NULL;
#else

  obj = 0;

#if (!defined(SWIG_PYTHON_SLOW_GETSET_THIS) && (PY_VERSION_HEX >= 0x02030000))
  if (PyInstance_Check(pyobj)) {
    obj = _PyInstance_Lookup(pyobj, SWIG_This());      
  } else {
    PyObject **dictptr = _PyObject_GetDictPtr(pyobj);
    if (dictptr != NULL) {
      PyObject *dict = *dictptr;
      obj = dict ? PyDict_GetItem(dict, SWIG_This()) : 0;
    } else {
#ifdef PyWeakref_CheckProxy
      if (PyWeakref_CheckProxy(pyobj)) {
	PyObject *wobj = PyWeakref_GET_OBJECT(pyobj);
	return wobj ? SWIG_Python_GetSwigThis(wobj) : 0;
      }
#endif
      obj = PyObject_GetAttr(pyobj,SWIG_This());
      if (obj) {
	Py_DECREF(obj);
      } else {
	if (PyErr_Occurred()) PyErr_Clear();
	return 0;
      }
    }
  }
#else
  obj = PyObject_GetAttr(pyobj,SWIG_This());
  if (obj) {
    Py_DECREF(obj);
  } else {
    if (PyErr_Occurred()) PyErr_Clear();
    return 0;
  }
#endif
  if (obj && !SwigPyObject_Check(obj)) {
    /* a PyObject is called 'this', try to get the 'real this'
       SwigPyObject from it */ 
    return SWIG_Python_GetSwigThis(obj);
  }
  return (SwigPyObject *)obj;
#endif
}

/* Acquire a pointer value */

SWIGRUNTIME int
SWIG_Python_AcquirePtr(PyObject *obj, int own) {
  if (own == SWIG_POINTER_OWN) {
    SwigPyObject *sobj = SWIG_Python_GetSwigThis(obj);
    if (sobj) {
      int oldown = sobj->own;
      sobj->own = own;
      return oldown;
    }
  }
  return 0;
}

/* Convert a pointer value */

SWIGRUNTIME int
SWIG_Python_ConvertPtrAndOwn(PyObject *obj, void **ptr, swig_type_info *ty, int flags, int *own) {
  int res;
  SwigPyObject *sobj;
  int implicit_conv = (flags & SWIG_POINTER_IMPLICIT_CONV) != 0;

  if (!obj)
    return SWIG_ERROR;
  if (obj == Py_None && !implicit_conv) {
    if (ptr)
      *ptr = 0;
    return SWIG_OK;
  }

  res = SWIG_ERROR;

  sobj = SWIG_Python_GetSwigThis(obj);
  if (own)
    *own = 0;
  while (sobj) {
    void *vptr = sobj->ptr;
    if (ty) {
      swig_type_info *to = sobj->ty;
      if (to == ty) {
        /* no type cast needed */
        if (ptr) *ptr = vptr;
        break;
      } else {
        swig_cast_info *tc = SWIG_TypeCheck(to->name,ty);
        if (!tc) {
          sobj = (SwigPyObject *)sobj->next;
        } else {
          if (ptr) {
            int newmemory = 0;
            *ptr = SWIG_TypeCast(tc,vptr,&newmemory);
            if (newmemory == SWIG_CAST_NEW_MEMORY) {
              assert(own); /* badly formed typemap which will lead to a memory leak - it must set and use own to delete *ptr */
              if (own)
                *own = *own | SWIG_CAST_NEW_MEMORY;
            }
          }
          break;
        }
      }
    } else {
      if (ptr) *ptr = vptr;
      break;
    }
  }
  if (sobj) {
    if (own)
      *own = *own | sobj->own;
    if (flags & SWIG_POINTER_DISOWN) {
      sobj->own = 0;
    }
    res = SWIG_OK;
  } else {
    if (implicit_conv) {
      SwigPyClientData *data = ty ? (SwigPyClientData *) ty->clientdata : 0;
      if (data && !data->implicitconv) {
        PyObject *klass = data->klass;
        if (klass) {
          PyObject *impconv;
          data->implicitconv = 1; /* avoid recursion and call 'explicit' constructors*/
          impconv = SWIG_Python_CallFunctor(klass, obj);
          data->implicitconv = 0;
          if (PyErr_Occurred()) {
            PyErr_Clear();
            impconv = 0;
          }
          if (impconv) {
            SwigPyObject *iobj = SWIG_Python_GetSwigThis(impconv);
            if (iobj) {
              void *vptr;
              res = SWIG_Python_ConvertPtrAndOwn((PyObject*)iobj, &vptr, ty, 0, 0);
              if (SWIG_IsOK(res)) {
                if (ptr) {
                  *ptr = vptr;
                  /* transfer the ownership to 'ptr' */
                  iobj->own = 0;
                  res = SWIG_AddCast(res);
                  res = SWIG_AddNewMask(res);
                } else {
                  res = SWIG_AddCast(res);		    
                }
              }
            }
            Py_DECREF(impconv);
          }
        }
      }
    }
    if (!SWIG_IsOK(res) && obj == Py_None) {
      if (ptr)
        *ptr = 0;
      if (PyErr_Occurred())
        PyErr_Clear();
      res = SWIG_OK;
    }
  }
  return res;
}

/* Convert a function ptr value */

SWIGRUNTIME int
SWIG_Python_ConvertFunctionPtr(PyObject *obj, void **ptr, swig_type_info *ty) {
  if (!PyCFunction_Check(obj)) {
    return SWIG_ConvertPtr(obj, ptr, ty, 0);
  } else {
    void *vptr = 0;
    
    /* here we get the method pointer for callbacks */
    const char *doc = (((PyCFunctionObject *)obj) -> m_ml -> ml_doc);
    const char *desc = doc ? strstr(doc, "swig_ptr: ") : 0;
    if (desc)
      desc = ty ? SWIG_UnpackVoidPtr(desc + 10, &vptr, ty->name) : 0;
    if (!desc) 
      return SWIG_ERROR;
    if (ty) {
      swig_cast_info *tc = SWIG_TypeCheck(desc,ty);
      if (tc) {
        int newmemory = 0;
        *ptr = SWIG_TypeCast(tc,vptr,&newmemory);
        assert(!newmemory); /* newmemory handling not yet implemented */
      } else {
        return SWIG_ERROR;
      }
    } else {
      *ptr = vptr;
    }
    return SWIG_OK;
  }
}

/* Convert a packed value value */

SWIGRUNTIME int
SWIG_Python_ConvertPacked(PyObject *obj, void *ptr, size_t sz, swig_type_info *ty) {
  swig_type_info *to = SwigPyPacked_UnpackData(obj, ptr, sz);
  if (!to) return SWIG_ERROR;
  if (ty) {
    if (to != ty) {
      /* check type cast? */
      swig_cast_info *tc = SWIG_TypeCheck(to->name,ty);
      if (!tc) return SWIG_ERROR;
    }
  }
  return SWIG_OK;
}  

/* -----------------------------------------------------------------------------
 * Create a new pointer object
 * ----------------------------------------------------------------------------- */

/*
  Create a new instance object, without calling __init__, and set the
  'this' attribute.
*/

SWIGRUNTIME PyObject* 
SWIG_Python_NewShadowInstance(SwigPyClientData *data, PyObject *swig_this)
{
#if (PY_VERSION_HEX >= 0x02020000)
  PyObject *inst = 0;
  PyObject *newraw = data->newraw;
  if (newraw) {
    inst = PyObject_Call(newraw, data->newargs, NULL);
    if (inst) {
#if !defined(SWIG_PYTHON_SLOW_GETSET_THIS)
      PyObject **dictptr = _PyObject_GetDictPtr(inst);
      if (dictptr != NULL) {
	PyObject *dict = *dictptr;
	if (dict == NULL) {
	  dict = PyDict_New();
	  *dictptr = dict;
	  PyDict_SetItem(dict, SWIG_This(), swig_this);
	}
      }
#else
      PyObject *key = SWIG_This();
      PyObject_SetAttr(inst, key, swig_this);
#endif
    }
  } else {
#if PY_VERSION_HEX >= 0x03000000
    inst = ((PyTypeObject*) data->newargs)->tp_new((PyTypeObject*) data->newargs, Py_None, Py_None);
    if (inst) {
      PyObject_SetAttr(inst, SWIG_This(), swig_this);
      Py_TYPE(inst)->tp_flags &= ~Py_TPFLAGS_VALID_VERSION_TAG;
    }
#else
    PyObject *dict = PyDict_New();
    if (dict) {
      PyDict_SetItem(dict, SWIG_This(), swig_this);
      inst = PyInstance_NewRaw(data->newargs, dict);
      Py_DECREF(dict);
    }
#endif
  }
  return inst;
#else
#if (PY_VERSION_HEX >= 0x02010000)
  PyObject *inst = 0;
  PyObject *dict = PyDict_New();
  if (dict) {
    PyDict_SetItem(dict, SWIG_This(), swig_this);
    inst = PyInstance_NewRaw(data->newargs, dict);
    Py_DECREF(dict);
  }
  return (PyObject *) inst;
#else
  PyInstanceObject *inst = PyObject_NEW(PyInstanceObject, &PyInstance_Type);
  if (inst == NULL) {
    return NULL;
  }
  inst->in_class = (PyClassObject *)data->newargs;
  Py_INCREF(inst->in_class);
  inst->in_dict = PyDict_New();
  if (inst->in_dict == NULL) {
    Py_DECREF(inst);
    return NULL;
  }
#ifdef Py_TPFLAGS_HAVE_WEAKREFS
  inst->in_weakreflist = NULL;
#endif
#ifdef Py_TPFLAGS_GC
  PyObject_GC_Init(inst);
#endif
  PyDict_SetItem(inst->in_dict, SWIG_This(), swig_this);
  return (PyObject *) inst;
#endif
#endif
}

SWIGRUNTIME void
SWIG_Python_SetSwigThis(PyObject *inst, PyObject *swig_this)
{
 PyObject *dict;
#if (PY_VERSION_HEX >= 0x02020000) && !defined(SWIG_PYTHON_SLOW_GETSET_THIS)
 PyObject **dictptr = _PyObject_GetDictPtr(inst);
 if (dictptr != NULL) {
   dict = *dictptr;
   if (dict == NULL) {
     dict = PyDict_New();
     *dictptr = dict;
   }
   PyDict_SetItem(dict, SWIG_This(), swig_this);
   return;
 }
#endif
 dict = PyObject_GetAttrString(inst, (char*)"__dict__");
 PyDict_SetItem(dict, SWIG_This(), swig_this);
 Py_DECREF(dict);
} 


SWIGINTERN PyObject *
SWIG_Python_InitShadowInstance(PyObject *args) {
  PyObject *obj[2];
  if (!SWIG_Python_UnpackTuple(args, "swiginit", 2, 2, obj)) {
    return NULL;
  } else {
    SwigPyObject *sthis = SWIG_Python_GetSwigThis(obj[0]);
    if (sthis) {
      SwigPyObject_append((PyObject*) sthis, obj[1]);
    } else {
      SWIG_Python_SetSwigThis(obj[0], obj[1]);
    }
    return SWIG_Py_Void();
  }
}

/* Create a new pointer object */

SWIGRUNTIME PyObject *
SWIG_Python_NewPointerObj(PyObject *self, void *ptr, swig_type_info *type, int flags) {
  SwigPyClientData *clientdata;
  PyObject * robj;
  int own;

  if (!ptr)
    return SWIG_Py_Void();

  clientdata = type ? (SwigPyClientData *)(type->clientdata) : 0;
  own = (flags & SWIG_POINTER_OWN) ? SWIG_POINTER_OWN : 0;
  if (clientdata && clientdata->pytype) {
    SwigPyObject *newobj;
    if (flags & SWIG_BUILTIN_TP_INIT) {
      newobj = (SwigPyObject*) self;
      if (newobj->ptr) {
        PyObject *next_self = clientdata->pytype->tp_alloc(clientdata->pytype, 0);
        while (newobj->next)
	  newobj = (SwigPyObject *) newobj->next;
        newobj->next = next_self;
        newobj = (SwigPyObject *)next_self;
      }
    } else {
      newobj = PyObject_New(SwigPyObject, clientdata->pytype);
    }
    if (newobj) {
      newobj->ptr = ptr;
      newobj->ty = type;
      newobj->own = own;
      newobj->next = 0;
#ifdef SWIGPYTHON_BUILTIN
      newobj->dict = 0;
#endif
      return (PyObject*) newobj;
    }
    return SWIG_Py_Void();
  }

  assert(!(flags & SWIG_BUILTIN_TP_INIT));

  robj = SwigPyObject_New(ptr, type, own);
  if (robj && clientdata && !(flags & SWIG_POINTER_NOSHADOW)) {
    PyObject *inst = SWIG_Python_NewShadowInstance(clientdata, robj);
    Py_DECREF(robj);
    robj = inst;
  }
  return robj;
}

/* Create a new packed object */

SWIGRUNTIMEINLINE PyObject *
SWIG_Python_NewPackedObj(void *ptr, size_t sz, swig_type_info *type) {
  return ptr ? SwigPyPacked_New((void *) ptr, sz, type) : SWIG_Py_Void();
}

/* -----------------------------------------------------------------------------*
 *  Get type list 
 * -----------------------------------------------------------------------------*/

#ifdef SWIG_LINK_RUNTIME
void *SWIG_ReturnGlobalTypeList(void *);
#endif

SWIGRUNTIME swig_module_info *
SWIG_Python_GetModule(void *SWIGUNUSEDPARM(clientdata)) {
  static void *type_pointer = (void *)0;
  /* first check if module already created */
  if (!type_pointer) {
#ifdef SWIG_LINK_RUNTIME
    type_pointer = SWIG_ReturnGlobalTypeList((void *)0);
#else
# ifdef SWIGPY_USE_CAPSULE
    type_pointer = PyCapsule_Import(SWIGPY_CAPSULE_NAME, 0);
# else
    type_pointer = PyCObject_Import((char*)"swig_runtime_data" SWIG_RUNTIME_VERSION,
				    (char*)"type_pointer" SWIG_TYPE_TABLE_NAME);
# endif
    if (PyErr_Occurred()) {
      PyErr_Clear();
      type_pointer = (void *)0;
    }
#endif
  }
  return (swig_module_info *) type_pointer;
}

#if PY_MAJOR_VERSION < 2
/* PyModule_AddObject function was introduced in Python 2.0.  The following function
   is copied out of Python/modsupport.c in python version 2.3.4 */
SWIGINTERN int
PyModule_AddObject(PyObject *m, char *name, PyObject *o)
{
  PyObject *dict;
  if (!PyModule_Check(m)) {
    PyErr_SetString(PyExc_TypeError,
		    "PyModule_AddObject() needs module as first arg");
    return SWIG_ERROR;
  }
  if (!o) {
    PyErr_SetString(PyExc_TypeError,
		    "PyModule_AddObject() needs non-NULL value");
    return SWIG_ERROR;
  }
  
  dict = PyModule_GetDict(m);
  if (dict == NULL) {
    /* Internal error -- modules must have a dict! */
    PyErr_Format(PyExc_SystemError, "module '%s' has no __dict__",
		 PyModule_GetName(m));
    return SWIG_ERROR;
  }
  if (PyDict_SetItemString(dict, name, o))
    return SWIG_ERROR;
  Py_DECREF(o);
  return SWIG_OK;
}
#endif

SWIGRUNTIME void
#ifdef SWIGPY_USE_CAPSULE
SWIG_Python_DestroyModule(PyObject *obj)
#else
SWIG_Python_DestroyModule(void *vptr)
#endif
{
#ifdef SWIGPY_USE_CAPSULE
  swig_module_info *swig_module = (swig_module_info *) PyCapsule_GetPointer(obj, SWIGPY_CAPSULE_NAME);
#else
  swig_module_info *swig_module = (swig_module_info *) vptr;
#endif
  swig_type_info **types = swig_module->types;
  size_t i;
  for (i =0; i < swig_module->size; ++i) {
    swig_type_info *ty = types[i];
    if (ty->owndata) {
      SwigPyClientData *data = (SwigPyClientData *) ty->clientdata;
      if (data) SwigPyClientData_Del(data);
    }
  }
  Py_DECREF(SWIG_This());
  swig_this = NULL;
}

SWIGRUNTIME void
SWIG_Python_SetModule(swig_module_info *swig_module) {
#if PY_VERSION_HEX >= 0x03000000
 /* Add a dummy module object into sys.modules */
  PyObject *module = PyImport_AddModule((char*)"swig_runtime_data" SWIG_RUNTIME_VERSION);
#else
  static PyMethodDef swig_empty_runtime_method_table[] = { {NULL, NULL, 0, NULL} }; /* Sentinel */
  PyObject *module = Py_InitModule((char*)"swig_runtime_data" SWIG_RUNTIME_VERSION, swig_empty_runtime_method_table);
#endif
#ifdef SWIGPY_USE_CAPSULE
  PyObject *pointer = PyCapsule_New((void *) swig_module, SWIGPY_CAPSULE_NAME, SWIG_Python_DestroyModule);
  if (pointer && module) {
    PyModule_AddObject(module, (char*)"type_pointer_capsule" SWIG_TYPE_TABLE_NAME, pointer);
  } else {
    Py_XDECREF(pointer);
  }
#else
  PyObject *pointer = PyCObject_FromVoidPtr((void *) swig_module, SWIG_Python_DestroyModule);
  if (pointer && module) {
    PyModule_AddObject(module, (char*)"type_pointer" SWIG_TYPE_TABLE_NAME, pointer);
  } else {
    Py_XDECREF(pointer);
  }
#endif
}

/* The python cached type query */
SWIGRUNTIME PyObject *
SWIG_Python_TypeCache(void) {
  static PyObject *SWIG_STATIC_POINTER(cache) = PyDict_New();
  return cache;
}

SWIGRUNTIME swig_type_info *
SWIG_Python_TypeQuery(const char *type)
{
  PyObject *cache = SWIG_Python_TypeCache();
  PyObject *key = SWIG_Python_str_FromChar(type); 
  PyObject *obj = PyDict_GetItem(cache, key);
  swig_type_info *descriptor;
  if (obj) {
#ifdef SWIGPY_USE_CAPSULE
    descriptor = (swig_type_info *) PyCapsule_GetPointer(obj, NULL);
#else
    descriptor = (swig_type_info *) PyCObject_AsVoidPtr(obj);
#endif
  } else {
    swig_module_info *swig_module = SWIG_GetModule(0);
    if (!swig_module) {
        return 0;
    }
    descriptor = SWIG_TypeQueryModule(swig_module, swig_module, type);
    if (descriptor) {
#ifdef SWIGPY_USE_CAPSULE
      obj = PyCapsule_New((void*) descriptor, NULL, NULL);
#else
      obj = PyCObject_FromVoidPtr(descriptor, NULL);
#endif
      PyDict_SetItem(cache, key, obj);
      Py_DECREF(obj);
    }
  }
  Py_DECREF(key);
  return descriptor;
}

/* 
   For backward compatibility only
*/
#define SWIG_POINTER_EXCEPTION  0
#define SWIG_arg_fail(arg)      SWIG_Python_ArgFail(arg)
#define SWIG_MustGetPtr(p, type, argnum, flags)  SWIG_Python_MustGetPtr(p, type, argnum, flags)

SWIGRUNTIME int
SWIG_Python_AddErrMesg(const char* mesg, int infront)
{  
  if (PyErr_Occurred()) {
    PyObject *type = 0;
    PyObject *value = 0;
    PyObject *traceback = 0;
    PyErr_Fetch(&type, &value, &traceback);
    if (value) {
      char *tmp;
      PyObject *old_str = PyObject_Str(value);
      Py_XINCREF(type);
      PyErr_Clear();
      if (infront) {
	PyErr_Format(type, "%s %s", mesg, tmp = SWIG_Python_str_AsChar(old_str));
      } else {
	PyErr_Format(type, "%s %s", tmp = SWIG_Python_str_AsChar(old_str), mesg);
      }
      SWIG_Python_str_DelForPy3(tmp);
      Py_DECREF(old_str);
    }
    return 1;
  } else {
    return 0;
  }
}
  
SWIGRUNTIME int
SWIG_Python_ArgFail(int argnum)
{
  if (PyErr_Occurred()) {
    /* add information about failing argument */
    char mesg[256];
    PyOS_snprintf(mesg, sizeof(mesg), "argument number %d:", argnum);
    return SWIG_Python_AddErrMesg(mesg, 1);
  } else {
    return 0;
  }
}

SWIGRUNTIMEINLINE const char *
SwigPyObject_GetDesc(PyObject *self)
{
  SwigPyObject *v = (SwigPyObject *)self;
  swig_type_info *ty = v ? v->ty : 0;
  return ty ? ty->str : "";
}

SWIGRUNTIME void
SWIG_Python_TypeError(const char *type, PyObject *obj)
{
  if (type) {
#if defined(SWIG_COBJECT_TYPES)
    if (obj && SwigPyObject_Check(obj)) {
      const char *otype = (const char *) SwigPyObject_GetDesc(obj);
      if (otype) {
	PyErr_Format(PyExc_TypeError, "a '%s' is expected, 'SwigPyObject(%s)' is received",
		     type, otype);
	return;
      }
    } else 
#endif      
    {
      const char *otype = (obj ? obj->ob_type->tp_name : 0); 
      if (otype) {
	PyObject *str = PyObject_Str(obj);
	const char *cstr = str ? SWIG_Python_str_AsChar(str) : 0;
	if (cstr) {
	  PyErr_Format(PyExc_TypeError, "a '%s' is expected, '%s(%s)' is received",
		       type, otype, cstr);
          SWIG_Python_str_DelForPy3(cstr);
	} else {
	  PyErr_Format(PyExc_TypeError, "a '%s' is expected, '%s' is received",
		       type, otype);
	}
	Py_XDECREF(str);
	return;
      }
    }   
    PyErr_Format(PyExc_TypeError, "a '%s' is expected", type);
  } else {
    PyErr_Format(PyExc_TypeError, "unexpected type is received");
  }
}


/* Convert a pointer value, signal an exception on a type mismatch */
SWIGRUNTIME void *
SWIG_Python_MustGetPtr(PyObject *obj, swig_type_info *ty, int SWIGUNUSEDPARM(argnum), int flags) {
  void *result;
  if (SWIG_Python_ConvertPtr(obj, &result, ty, flags) == -1) {
    PyErr_Clear();
#if SWIG_POINTER_EXCEPTION
    if (flags) {
      SWIG_Python_TypeError(SWIG_TypePrettyName(ty), obj);
      SWIG_Python_ArgFail(argnum);
    }
#endif
  }
  return result;
}

#ifdef SWIGPYTHON_BUILTIN
SWIGRUNTIME int
SWIG_Python_NonDynamicSetAttr(PyObject *obj, PyObject *name, PyObject *value) {
  PyTypeObject *tp = obj->ob_type;
  PyObject *descr;
  PyObject *encoded_name;
  descrsetfunc f;
  int res = -1;

# ifdef Py_USING_UNICODE
  if (PyString_Check(name)) {
    name = PyUnicode_Decode(PyString_AsString(name), PyString_Size(name), NULL, NULL);
    if (!name)
      return -1;
  } else if (!PyUnicode_Check(name))
# else
  if (!PyString_Check(name))
# endif
  {
    PyErr_Format(PyExc_TypeError, "attribute name must be string, not '%.200s'", name->ob_type->tp_name);
    return -1;
  } else {
    Py_INCREF(name);
  }

  if (!tp->tp_dict) {
    if (PyType_Ready(tp) < 0)
      goto done;
  }

  descr = _PyType_Lookup(tp, name);
  f = NULL;
  if (descr != NULL)
    f = descr->ob_type->tp_descr_set;
  if (!f) {
    if (PyString_Check(name)) {
      encoded_name = name;
      Py_INCREF(name);
    } else {
      encoded_name = PyUnicode_AsUTF8String(name);
    }
    PyErr_Format(PyExc_AttributeError, "'%.100s' object has no attribute '%.200s'", tp->tp_name, PyString_AsString(encoded_name));
    Py_DECREF(encoded_name);
  } else {
    res = f(descr, obj, value);
  }
  
  done:
  Py_DECREF(name);
  return res;
}
#endif


#ifdef __cplusplus
}
#endif



#define SWIG_exception_fail(code, msg) do { SWIG_Error(code, msg); SWIG_fail; } while(0) 

#define SWIG_contract_assert(expr, msg) if (!(expr)) { SWIG_Error(SWIG_RuntimeError, msg); SWIG_fail; } else 



  #define SWIG_exception(code, msg) do { SWIG_Error(code, msg); SWIG_fail;; } while(0) 

/* -----------------------------------------------------------------------------
 * director_common.swg
 *
 * This file contains support for director classes which is common between
 * languages.
 * ----------------------------------------------------------------------------- */

/*
  Use -DSWIG_DIRECTOR_STATIC if you prefer to avoid the use of the
  'Swig' namespace. This could be useful for multi-modules projects.
*/
#ifdef SWIG_DIRECTOR_STATIC
/* Force anonymous (static) namespace */
#define Swig
#endif
/* -----------------------------------------------------------------------------
 * director.swg
 *
 * This file contains support for director classes so that Python proxy
 * methods can be called from C++.
 * ----------------------------------------------------------------------------- */

#ifndef SWIG_DIRECTOR_PYTHON_HEADER_
#define SWIG_DIRECTOR_PYTHON_HEADER_

#include <string>
#include <iostream>
#include <exception>
#include <vector>
#include <map>


/*
  Use -DSWIG_PYTHON_DIRECTOR_NO_VTABLE if you don't want to generate a 'virtual
  table', and avoid multiple GetAttr calls to retrieve the python
  methods.
*/

#ifndef SWIG_PYTHON_DIRECTOR_NO_VTABLE
#ifndef SWIG_PYTHON_DIRECTOR_VTABLE
#define SWIG_PYTHON_DIRECTOR_VTABLE
#endif
#endif



/*
  Use -DSWIG_DIRECTOR_NO_UEH if you prefer to avoid the use of the
  Undefined Exception Handler provided by swig.
*/
#ifndef SWIG_DIRECTOR_NO_UEH
#ifndef SWIG_DIRECTOR_UEH
#define SWIG_DIRECTOR_UEH
#endif
#endif


/*
  Use -DSWIG_DIRECTOR_NORTTI if you prefer to avoid the use of the
  native C++ RTTI and dynamic_cast<>. But be aware that directors
  could stop working when using this option.
*/
#ifdef SWIG_DIRECTOR_NORTTI
/*
   When we don't use the native C++ RTTI, we implement a minimal one
   only for Directors.
*/
# ifndef SWIG_DIRECTOR_RTDIR
# define SWIG_DIRECTOR_RTDIR

namespace Swig {
  class Director;
  SWIGINTERN std::map<void *, Director *>& get_rtdir_map() {
    static std::map<void *, Director *> rtdir_map;
    return rtdir_map;
  }

  SWIGINTERNINLINE void set_rtdir(void *vptr, Director *rtdir) {
    get_rtdir_map()[vptr] = rtdir;
  }

  SWIGINTERNINLINE Director *get_rtdir(void *vptr) {
    std::map<void *, Director *>::const_iterator pos = get_rtdir_map().find(vptr);
    Director *rtdir = (pos != get_rtdir_map().end()) ? pos->second : 0;
    return rtdir;
  }
}
# endif /* SWIG_DIRECTOR_RTDIR */

# define SWIG_DIRECTOR_CAST(ARG) Swig::get_rtdir(static_cast<void *>(ARG))
# define SWIG_DIRECTOR_RGTR(ARG1, ARG2) Swig::set_rtdir(static_cast<void *>(ARG1), ARG2)

#else

# define SWIG_DIRECTOR_CAST(ARG) dynamic_cast<Swig::Director *>(ARG)
# define SWIG_DIRECTOR_RGTR(ARG1, ARG2)

#endif /* SWIG_DIRECTOR_NORTTI */

extern "C" {
  struct swig_type_info;
}

namespace Swig {

  /* memory handler */
  struct GCItem {
    virtual ~GCItem() {}

    virtual int get_own() const {
      return 0;
    }
  };

  struct GCItem_var {
    GCItem_var(GCItem *item = 0) : _item(item) {
    }

    GCItem_var& operator=(GCItem *item) {
      GCItem *tmp = _item;
      _item = item;
      delete tmp;
      return *this;
    }

    ~GCItem_var() {
      delete _item;
    }

    GCItem * operator->() const {
      return _item;
    }

  private:
    GCItem *_item;
  };

  struct GCItem_Object : GCItem {
    GCItem_Object(int own) : _own(own) {
    }

    virtual ~GCItem_Object() {
    }

    int get_own() const {
      return _own;
    }

  private:
    int _own;
  };

  template <typename Type>
  struct GCItem_T : GCItem {
    GCItem_T(Type *ptr) : _ptr(ptr) {
    }

    virtual ~GCItem_T() {
      delete _ptr;
    }

  private:
    Type *_ptr;
  };

  template <typename Type>
  struct GCArray_T : GCItem {
    GCArray_T(Type *ptr) : _ptr(ptr) {
    }

    virtual ~GCArray_T() {
      delete[] _ptr;
    }

  private:
    Type *_ptr;
  };

  /* base class for director exceptions */
  class DirectorException : public std::exception {
  protected:
    std::string swig_msg;
  public:
    DirectorException(PyObject *error, const char *hdr ="", const char *msg ="") : swig_msg(hdr) {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      if (msg[0]) {
        swig_msg += " ";
        swig_msg += msg;
      }
      if (!PyErr_Occurred()) {
        PyErr_SetString(error, what());
      }
      SWIG_PYTHON_THREAD_END_BLOCK;
    }

    virtual ~DirectorException() throw() {
    }

    /* Deprecated, use what() instead */
    const char *getMessage() const {
      return what();
    }

    const char *what() const throw() {
      return swig_msg.c_str();
    }

    static void raise(PyObject *error, const char *msg) {
      throw DirectorException(error, msg);
    }

    static void raise(const char *msg) {
      raise(PyExc_RuntimeError, msg);
    }
  };

  /* unknown exception handler  */
  class UnknownExceptionHandler {
#ifdef SWIG_DIRECTOR_UEH
    static void handler() {
      try {
        throw;
      } catch (DirectorException& e) {
        std::cerr << "SWIG Director exception caught:" << std::endl
                  << e.what() << std::endl;
      } catch (std::exception& e) {
        std::cerr << "std::exception caught: "<< e.what() << std::endl;
      } catch (...) {
        std::cerr << "Unknown exception caught." << std::endl;
      }

      std::cerr << std::endl
                << "Python interpreter traceback:" << std::endl;
      PyErr_Print();
      std::cerr << std::endl;

      std::cerr << "This exception was caught by the SWIG unexpected exception handler." << std::endl
                << "Try using %feature(\"director:except\") to avoid reaching this point." << std::endl
                << std::endl
                << "Exception is being re-thrown, program will likely abort/terminate." << std::endl;
      throw;
    }

  public:

    std::unexpected_handler old;
    UnknownExceptionHandler(std::unexpected_handler nh = handler) {
      old = std::set_unexpected(nh);
    }

    ~UnknownExceptionHandler() {
      std::set_unexpected(old);
    }
#endif
  };

  /* type mismatch in the return value from a python method call */
  class DirectorTypeMismatchException : public DirectorException {
  public:
    DirectorTypeMismatchException(PyObject *error, const char *msg="")
      : DirectorException(error, "SWIG director type mismatch", msg) {
    }

    DirectorTypeMismatchException(const char *msg="")
      : DirectorException(PyExc_TypeError, "SWIG director type mismatch", msg) {
    }

    static void raise(PyObject *error, const char *msg) {
      throw DirectorTypeMismatchException(error, msg);
    }

    static void raise(const char *msg) {
      throw DirectorTypeMismatchException(msg);
    }
  };

  /* any python exception that occurs during a director method call */
  class DirectorMethodException : public DirectorException {
  public:
    DirectorMethodException(const char *msg = "")
      : DirectorException(PyExc_RuntimeError, "SWIG director method error.", msg) {
    }

    static void raise(const char *msg) {
      throw DirectorMethodException(msg);
    }
  };

  /* attempt to call a pure virtual method via a director method */
  class DirectorPureVirtualException : public DirectorException {
  public:
    DirectorPureVirtualException(const char *msg = "")
      : DirectorException(PyExc_RuntimeError, "SWIG director pure virtual method called", msg) {
    }

    static void raise(const char *msg) {
      throw DirectorPureVirtualException(msg);
    }
  };


#if defined(SWIG_PYTHON_THREADS)
/*  __THREAD__ is the old macro to activate some thread support */
# if !defined(__THREAD__)
#   define __THREAD__ 1
# endif
#endif

#ifdef __THREAD__
# include "pythread.h"
  class Guard {
    PyThread_type_lock &mutex_;

  public:
    Guard(PyThread_type_lock & mutex) : mutex_(mutex) {
      PyThread_acquire_lock(mutex_, WAIT_LOCK);
    }

    ~Guard() {
      PyThread_release_lock(mutex_);
    }
  };
# define SWIG_GUARD(mutex) Guard _guard(mutex)
#else
# define SWIG_GUARD(mutex)
#endif

  /* director base class */
  class Director {
  private:
    /* pointer to the wrapped python object */
    PyObject *swig_self;
    /* flag indicating whether the object is owned by python or c++ */
    mutable bool swig_disown_flag;

    /* decrement the reference count of the wrapped python object */
    void swig_decref() const {
      if (swig_disown_flag) {
        SWIG_PYTHON_THREAD_BEGIN_BLOCK;
        Py_DECREF(swig_self);
        SWIG_PYTHON_THREAD_END_BLOCK;
      }
    }

  public:
    /* wrap a python object, optionally taking ownership */
    Director(PyObject *self) : swig_self(self), swig_disown_flag(false) {
      swig_incref();
    }

    /* discard our reference at destruction */
    virtual ~Director() {
      swig_decref();
    }

    /* return a pointer to the wrapped python object */
    PyObject *swig_get_self() const {
      return swig_self;
    }

    /* acquire ownership of the wrapped python object (the sense of "disown" is from python) */
    void swig_disown() const {
      if (!swig_disown_flag) {
        swig_disown_flag=true;
        swig_incref();
      }
    }

    /* increase the reference count of the wrapped python object */
    void swig_incref() const {
      if (swig_disown_flag) {
        Py_INCREF(swig_self);
      }
    }

    /* methods to implement pseudo protected director members */
    virtual bool swig_get_inner(const char * /* swig_protected_method_name */) const {
      return true;
    }

    virtual void swig_set_inner(const char * /* swig_protected_method_name */, bool /* swig_val */) const {
    }

  /* ownership management */
  private:
    typedef std::map<void *, GCItem_var> swig_ownership_map;
    mutable swig_ownership_map swig_owner;
#ifdef __THREAD__
    static PyThread_type_lock swig_mutex_own;
#endif

  public:
    template <typename Type>
    void swig_acquire_ownership_array(Type *vptr) const {
      if (vptr) {
        SWIG_GUARD(swig_mutex_own);
        swig_owner[vptr] = new GCArray_T<Type>(vptr);
      }
    }

    template <typename Type>
    void swig_acquire_ownership(Type *vptr) const {
      if (vptr) {
        SWIG_GUARD(swig_mutex_own);
        swig_owner[vptr] = new GCItem_T<Type>(vptr);
      }
    }

    void swig_acquire_ownership_obj(void *vptr, int own) const {
      if (vptr && own) {
        SWIG_GUARD(swig_mutex_own);
        swig_owner[vptr] = new GCItem_Object(own);
      }
    }

    int swig_release_ownership(void *vptr) const {
      int own = 0;
      if (vptr) {
        SWIG_GUARD(swig_mutex_own);
        swig_ownership_map::iterator iter = swig_owner.find(vptr);
        if (iter != swig_owner.end()) {
          own = iter->second->get_own();
          swig_owner.erase(iter);
        }
      }
      return own;
    }

    template <typename Type>
    static PyObject *swig_pyobj_disown(PyObject *pyobj, PyObject *SWIGUNUSEDPARM(args)) {
      SwigPyObject *sobj = (SwigPyObject *)pyobj;
      sobj->own = 0;
      Director *d = SWIG_DIRECTOR_CAST(reinterpret_cast<Type *>(sobj->ptr));
      if (d)
        d->swig_disown();
      return PyWeakref_NewProxy(pyobj, NULL);
    }
  };

#ifdef __THREAD__
  PyThread_type_lock Director::swig_mutex_own = PyThread_allocate_lock();
#endif
}

#endif

/* -------- TYPES TABLE (BEGIN) -------- */

#define SWIGTYPE_p_baseDataType swig_types[0]
#define SWIGTYPE_p_char swig_types[1]
#define SWIGTYPE_p_daal__data_management__features__interface1__FeatureIdCollection swig_types[2]
#define SWIGTYPE_p_daal__data_management__features__interface1__FeatureIdCollectionIface swig_types[3]
#define SWIGTYPE_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t swig_types[4]
#define SWIGTYPE_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t swig_types[5]
#define SWIGTYPE_p_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t swig_types[6]
#define SWIGTYPE_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t swig_types[7]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__Base_t swig_types[8]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t swig_types[9]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t swig_types[10]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t swig_types[11]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t swig_types[12]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t swig_types[13]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t swig_types[14]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t swig_types[15]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t swig_types[16]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t swig_types[17]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__Prediction_t swig_types[18]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t swig_types[19]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t swig_types[20]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t swig_types[21]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__BatchBase_t swig_types[22]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__FamilyBatchBase_t swig_types[23]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__Input_t swig_types[24]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__Result_t swig_types[25]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__engines__mt19937__interface1__BatchT_double_daal__algorithms__engines__mt19937__defaultDense_t_t swig_types[26]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__engines__mt19937__interface1__BatchT_float_daal__algorithms__engines__mt19937__defaultDense_t_t swig_types[27]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t swig_types[28]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t swig_types[29]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t swig_types[30]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t swig_types[31]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t swig_types[32]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t swig_types[33]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t swig_types[34]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t swig_types[35]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmDispatchContainer_t swig_types[36]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t swig_types[37]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t swig_types[38]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t swig_types[39]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t swig_types[40]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t swig_types[41]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t swig_types[42]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t swig_types[43]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t swig_types[44]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t swig_types[45]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__HostAppIface_t swig_types[46]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t swig_types[47]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Kernel_t swig_types[48]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t swig_types[49]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t swig_types[50]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Parameter_t swig_types[51]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t swig_types[52]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t swig_types[53]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t swig_types[54]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t swig_types[55]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t swig_types[56]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t swig_types[57]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t swig_types[58]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t swig_types[59]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t swig_types[60]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndexTraits_t swig_types[61]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t swig_types[62]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t swig_types[63]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BasicStatisticsDataCollection_t swig_types[64]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t swig_types[65]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t swig_types[66]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t swig_types[67]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t swig_types[68]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t swig_types[69]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t swig_types[70]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t swig_types[71]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t swig_types[72]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t swig_types[73]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CategoricalFeatureDictionary_t swig_types[74]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__ColumnFilter_t swig_types[75]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t swig_types[76]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t swig_types[77]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t swig_types[78]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t swig_types[79]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t swig_types[80]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t swig_types[81]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t swig_types[82]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t swig_types[83]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t swig_types[84]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t swig_types[85]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t swig_types[86]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t swig_types[87]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t swig_types[88]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t swig_types[89]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t swig_types[90]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t swig_types[91]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t swig_types[92]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t swig_types[93]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t swig_types[94]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t swig_types[95]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t swig_types[96]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t swig_types[97]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t swig_types[98]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t swig_types[99]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t swig_types[100]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t swig_types[101]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t swig_types[102]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t swig_types[103]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t swig_types[104]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t swig_types[105]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t swig_types[106]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t swig_types[107]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t swig_types[108]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t swig_types[109]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollectionIface_t swig_types[110]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollection_t swig_types[111]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdIface_t swig_types[112]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMappingIface_t swig_types[113]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMapping_t swig_types[114]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureId_t swig_types[115]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndexTraits_t swig_types[116]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndicesIface_t swig_types[117]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndices_t swig_types[118]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t swig_types[119]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t swig_types[120]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t swig_types[121]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t swig_types[122]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t swig_types[123]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t swig_types[124]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t swig_types[125]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t swig_types[126]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_const_t swig_types[127]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t swig_types[128]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t swig_types[129]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MakeCategorical_t swig_types[130]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t swig_types[131]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t swig_types[132]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t swig_types[133]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t swig_types[134]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__ModifierIface_t swig_types[135]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t swig_types[136]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t swig_types[137]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t swig_types[138]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_const_t swig_types[139]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t swig_types[140]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OneHotEncoder_t swig_types[141]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t swig_types[142]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t swig_types[143]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t swig_types[144]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t swig_types[145]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t swig_types[146]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t swig_types[147]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t swig_types[148]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t swig_types[149]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t swig_types[150]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t swig_types[151]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t swig_types[152]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t swig_types[153]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t swig_types[154]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t swig_types[155]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t swig_types[156]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t swig_types[157]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_const_t swig_types[158]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t swig_types[159]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t swig_types[160]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t swig_types[161]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t swig_types[162]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t swig_types[163]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t swig_types[164]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t swig_types[165]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t swig_types[166]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t swig_types[167]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t swig_types[168]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t swig_types[169]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t swig_types[170]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t swig_types[171]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t swig_types[172]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t swig_types[173]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t swig_types[174]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t swig_types[175]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t swig_types[176]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t swig_types[177]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t swig_types[178]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t swig_types[179]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__backward__LayerIfacePtr_t_t swig_types[180]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__LayerIfacePtr_t_t swig_types[181]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__interface1__LayerDescriptor_t_t swig_types[182]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__interface1__NextLayers_t_t swig_types[183]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__data_management__interface1__SerializationIfacePtr_t_t swig_types[184]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t swig_types[185]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__Environment_t swig_types[186]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__ErrorCollection_t swig_types[187]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__Error_t swig_types[188]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__KernelErrorCollection_t swig_types[189]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t swig_types[190]
#define SWIGTYPE_p_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t swig_types[191]
#define SWIGTYPE_p_env swig_types[192]
#define SWIGTYPE_p_first_type swig_types[193]
#define SWIGTYPE_p_numericTableType swig_types[194]
#define SWIGTYPE_p_second_type swig_types[195]
#define SWIGTYPE_p_size_t swig_types[196]
#define SWIGTYPE_p_super swig_types[197]
#define SWIGTYPE_p_unsigned_char swig_types[198]
static swig_type_info *swig_types[200];
static swig_module_info swig_module = {swig_types, 199, 0, 0, 0, 0};
#define SWIG_TypeQuery(name) SWIG_TypeQueryModule(&swig_module, &swig_module, name)
#define SWIG_MangledTypeQuery(name) SWIG_MangledTypeQueryModule(&swig_module, &swig_module, name)

/* -------- TYPES TABLE (END) -------- */

#if (PY_VERSION_HEX <= 0x02000000)
# if !defined(SWIG_PYTHON_CLASSIC)
#  error "This python version requires swig to be run with the '-classic' option"
# endif
#endif

/*-----------------------------------------------
              @(target):= _decision_forest_.so
  ------------------------------------------------*/
#if PY_VERSION_HEX >= 0x03000000
#  define SWIG_init    PyInit__decision_forest_

#else
#  define SWIG_init    init_decision_forest_

#endif
#define SWIG_name    "_decision_forest_"

#define SWIGVERSION 0x030006 
#define SWIG_VERSION SWIGVERSION


#define SWIG_as_voidptr(a) const_cast< void * >(static_cast< const void * >(a)) 
#define SWIG_as_voidptrptr(a) ((void)SWIG_as_voidptr(*a),reinterpret_cast< void** >(a)) 


#include <stdexcept>


namespace swig {
  class SwigPtr_PyObject {
  protected:
    PyObject *_obj;

  public:
    SwigPtr_PyObject() :_obj(0)
    {
    }

    SwigPtr_PyObject(const SwigPtr_PyObject& item) : _obj(item._obj)
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      Py_XINCREF(_obj);      
      SWIG_PYTHON_THREAD_END_BLOCK;
    }
    
    SwigPtr_PyObject(PyObject *obj, bool initial_ref = true) :_obj(obj)
    {
      if (initial_ref) {
        SWIG_PYTHON_THREAD_BEGIN_BLOCK;
        Py_XINCREF(_obj);
        SWIG_PYTHON_THREAD_END_BLOCK;
      }
    }
    
    SwigPtr_PyObject & operator=(const SwigPtr_PyObject& item) 
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      Py_XINCREF(item._obj);
      Py_XDECREF(_obj);
      _obj = item._obj;
      SWIG_PYTHON_THREAD_END_BLOCK;
      return *this;      
    }
    
    ~SwigPtr_PyObject() 
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      Py_XDECREF(_obj);
      SWIG_PYTHON_THREAD_END_BLOCK;
    }
    
    operator PyObject *() const
    {
      return _obj;
    }

    PyObject *operator->() const
    {
      return _obj;
    }
  };
}


namespace swig {
  struct SwigVar_PyObject : SwigPtr_PyObject {
    SwigVar_PyObject(PyObject* obj = 0) : SwigPtr_PyObject(obj, false) { }
    
    SwigVar_PyObject & operator = (PyObject* obj)
    {
      Py_XDECREF(_obj);
      _obj = obj;
      return *this;      
    }
  };
}


#define SWIG_FILE_WITH_INIT
//#define DAAL_NOTHROW_EXCEPTIONS // for DAAL_ResultErrorsException
//#define protected public //for DAAL_ResultErrorsException

#if PY_MAJOR_VERSION >= 3
# define PyInt_AsSsize_t PyLong_AsSsize_t
# define CHECK_STRING(s) PyUnicode_Check(s)
# define GET_STRING(s) PyUnicode_AsUTF8(s)
#else
# define CHECK_STRING(s) PyString_Check(s)
# define GET_STRING(s) PyString_AsString(s)
#endif

#include <daal.h>
#include <data_management/data_source/modifiers/csv/pyfeaturemodifier.h>


#include <string>


#include <stddef.h>


namespace swig {
  struct stop_iteration {
  };

  struct SwigPyIterator {
  private:
    SwigPtr_PyObject _seq;

  protected:
    SwigPyIterator(PyObject *seq) : _seq(seq)
    {
    }
      
  public:
    virtual ~SwigPyIterator() {}

    // Access iterator method, required by Python
    virtual PyObject *value() const = 0;

    // Forward iterator method, required by Python
    virtual SwigPyIterator *incr(size_t n = 1) = 0;
    
    // Backward iterator method, very common in C++, but not required in Python
    virtual SwigPyIterator *decr(size_t /*n*/ = 1)
    {
      throw stop_iteration();
    }

    // Random access iterator methods, but not required in Python
    virtual ptrdiff_t distance(const SwigPyIterator &/*x*/) const
    {
      throw std::invalid_argument("operation not supported");
    }

    virtual bool equal (const SwigPyIterator &/*x*/) const
    {
      throw std::invalid_argument("operation not supported");
    }
    
    // C++ common/needed methods
    virtual SwigPyIterator *copy() const = 0;

    PyObject *next()     
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK; // disable threads       
      PyObject *obj = value();
      incr();       
      SWIG_PYTHON_THREAD_END_BLOCK; // re-enable threads
      return obj;     
    }

    /* Make an alias for Python 3.x */
    PyObject *__next__()
    {
      return next();
    }

    PyObject *previous()
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK; // disable threads       
      decr();
      PyObject *obj = value();
      SWIG_PYTHON_THREAD_END_BLOCK; // re-enable threads       
      return obj;
    }

    SwigPyIterator *advance(ptrdiff_t n)
    {
      return  (n > 0) ?  incr(n) : decr(-n);
    }
      
    bool operator == (const SwigPyIterator& x)  const
    {
      return equal(x);
    }
      
    bool operator != (const SwigPyIterator& x) const
    {
      return ! operator==(x);
    }
      
    SwigPyIterator& operator += (ptrdiff_t n)
    {
      return *advance(n);
    }

    SwigPyIterator& operator -= (ptrdiff_t n)
    {
      return *advance(-n);
    }
      
    SwigPyIterator* operator + (ptrdiff_t n) const
    {
      return copy()->advance(n);
    }

    SwigPyIterator* operator - (ptrdiff_t n) const
    {
      return copy()->advance(-n);
    }
      
    ptrdiff_t operator - (const SwigPyIterator& x) const
    {
      return x.distance(*this);
    }
      
    static swig_type_info* descriptor() {
      static int init = 0;
      static swig_type_info* desc = 0;
      if (!init) {
	desc = SWIG_TypeQuery("swig::SwigPyIterator *");
	init = 1;
      }	
      return desc;
    }    
  };

#if defined(SWIGPYTHON_BUILTIN)
  inline PyObject* make_output_iterator_builtin (PyObject *pyself)
  {
    Py_INCREF(pyself);
    return pyself;
  }
#endif
}


#include <algorithm>


#include <daal.h>
using namespace daal::algorithms::decision_forest;



/* ---------------------------------------------------
 * C++ director class methods
 * --------------------------------------------------- */

#include "_algorithms__decision_forest.h"

#ifdef __cplusplus
extern "C" {
#endif
static PyMethodDef SwigMethods[] = {
	 { (char *)"SWIG_PyInstanceMethod_New", (PyCFunction)SWIG_PyInstanceMethod_New, METH_O, NULL},
	 { NULL, NULL, 0, NULL }
};


/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (BEGIN) -------- */

static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::FeatureModifier >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::PyFeatureModifier > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::FeatureModifierIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::FeatureModifier > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::FeatureModifierIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::PyFeatureModifier > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::ContextIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Context > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::ConfigIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Config > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::interface1::ContextIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::ContextIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::interface1::ContextIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Context > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::interface1::ConfigIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::ConfigIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::interface1::ConfigIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Config > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIndicesIface >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIndices > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdCollectionIface >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdCollection > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdIface >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureId > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdMappingIface >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdMapping > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > >(*(daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > >(*(daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > >(*(daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > >(*(daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > >(*(daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > >(*(daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DictionaryIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DictionaryIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Tensor > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSource > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface >(*(daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface >(*(daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSource >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSource >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSource >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSource >(*(daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSource >(*(daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSource >(*(daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataBlockIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataBlock > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::DataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Compression > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::SerializableArgument > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::PartialResult > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::Result > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::OptionalArgument > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::Model > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataCollection > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::TensorLayout > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Tensor > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::StringRowFeatureManagerIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Tensor >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Tensor >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Tensor >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::TensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Tensor > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::TensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::TensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::TensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::TensorLayoutIface >(*(daal::services::SharedPtr< daal::data_management::interface1::TensorLayout > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::TensorLayoutIface >(*(daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::TensorLayout >(*(daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::online > >(*(daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::batch > >(*(daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::batch > >(*(daal::services::SharedPtr< daal::algorithms::PredictionContainerIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::distributed > >(*(daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::distributed > >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::distributed > >(*(daal::services::SharedPtr< daal::algorithms::DistributedPredictionContainerIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::online > >(*(daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::online > >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::batch > >(*(daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::batch > >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::batch > >(*(daal::services::SharedPtr< daal::algorithms::PredictionContainerIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::distributed > >(*(daal::services::SharedPtr< daal::algorithms::Analysis< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::distributed > >(*(daal::services::SharedPtr< daal::algorithms::Training< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::distributed > >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::distributed > >(*(daal::services::SharedPtr< daal::algorithms::DistributedPrediction > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::online > >(*(daal::services::SharedPtr< daal::algorithms::Analysis< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::online > >(*(daal::services::SharedPtr< daal::algorithms::Training< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::online > >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::batch > >(*(daal::services::SharedPtr< daal::algorithms::Analysis< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::batch > >(*(daal::services::SharedPtr< daal::algorithms::Training< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::batch > >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__Prediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::batch > >(*(daal::services::SharedPtr< daal::algorithms::Prediction > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::SerializableArgument >(*(daal::services::SharedPtr< daal::algorithms::interface1::PartialResult > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::SerializableArgument >(*(daal::services::SharedPtr< daal::algorithms::interface1::Result > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::SerializableArgument >(*(daal::services::SharedPtr< daal::algorithms::interface1::OptionalArgument > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Argument >(*(daal::services::SharedPtr< daal::algorithms::interface1::SerializableArgument > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Argument >(*(daal::services::SharedPtr< daal::algorithms::interface1::Input > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Argument >(*(daal::services::SharedPtr< daal::algorithms::interface1::PartialResult > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Argument >(*(daal::services::SharedPtr< daal::algorithms::interface1::Result > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::Argument >(*(daal::services::SharedPtr< daal::algorithms::interface1::OptionalArgument > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::Training< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::Training< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::Training< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::Analysis< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::Analysis< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::Analysis< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::DistributedPrediction > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__Prediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::Prediction > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface >(*(daal::services::SharedPtr< daal::algorithms::Training< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface >(*(daal::services::SharedPtr< daal::algorithms::Training< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface >(*(daal::services::SharedPtr< daal::algorithms::Training< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface >(*(daal::services::SharedPtr< daal::algorithms::Analysis< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface >(*(daal::services::SharedPtr< daal::algorithms::Analysis< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface >(*(daal::services::SharedPtr< daal::algorithms::Analysis< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface >(*(daal::services::SharedPtr< daal::algorithms::DistributedPrediction > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__Prediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface >(*(daal::services::SharedPtr< daal::algorithms::Prediction > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::PredictionContainerIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIfaceImpl >(*(daal::services::SharedPtr< daal::algorithms::DistributedPredictionContainerIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIface >(*(daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIface >(*(daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIface >(*(daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIfaceImpl > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIface >(*(daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIface >(*(daal::services::SharedPtr< daal::algorithms::PredictionContainerIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIface >(*(daal::services::SharedPtr< daal::algorithms::DistributedPredictionContainerIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::distributed > >(*(daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::distributed > >(*(daal::services::SharedPtr< daal::algorithms::DistributedPredictionContainerIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::batch > >(*(daal::services::SharedPtr< daal::algorithms::Analysis< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::batch > >(*(daal::services::SharedPtr< daal::algorithms::Training< daal::batch > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__Prediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::batch > >(*(daal::services::SharedPtr< daal::algorithms::Prediction > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::online > >(*(daal::services::SharedPtr< daal::algorithms::Analysis< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::online > >(*(daal::services::SharedPtr< daal::algorithms::Training< daal::online > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::distributed > >(*(daal::services::SharedPtr< daal::algorithms::Analysis< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::distributed > >(*(daal::services::SharedPtr< daal::algorithms::Training< daal::distributed > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::distributed > >(*(daal::services::SharedPtr< daal::algorithms::DistributedPrediction > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::algorithms::interface1::SerializableArgument > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::algorithms::interface1::PartialResult > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::algorithms::interface1::Result > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::algorithms::interface1::OptionalArgument > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::algorithms::interface1::Model > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIndices > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdCollection > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureId > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdMapping > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::Tensor > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::TensorLayout > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DataCollection > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DataBlockIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DataBlock > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Config > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Context > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::FeatureModifier > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::PyFeatureModifier > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::services::interface1::LibraryVersionInfo > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__services__interface1__Environment_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::services::interface1::Environment > *)x);
}
static void *_p_daal__data_management__features__interface1__FeatureIdCollectionTo_p_daal__data_management__features__interface1__FeatureIdCollectionIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::features::interface1::FeatureIdCollectionIface *)  ((daal::data_management::features::interface1::FeatureIdCollection *) x));
}
static swig_type_info _swigt__p_baseDataType = {"_p_baseDataType", "baseDataType *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_char = {"_p_char", "char *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__features__interface1__FeatureIdCollectionIface = {"_p_daal__data_management__features__interface1__FeatureIdCollectionIface", "daal::data_management::features::FeatureIdCollectionIface *|daal::data_management::features::interface1::FeatureIdCollectionIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__features__interface1__FeatureIdCollection = {"_p_daal__data_management__features__interface1__FeatureIdCollection", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t = {"_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t", "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *|daal::data_management::interface1::DataSourceDictionary *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t = {"_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t", "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *|daal::data_management::interface1::NumericTableDictionary *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t = {"_p_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t", "daal::data_management::interface1::KeyValueInputCollection *|daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t = {"_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t", "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *|daal::data_management::interface1::KeyValueDataCollection *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__Base_t = {"_p_daal__services__SharedPtrT_daal__Base_t", "daal::services::SharedPtr< daal::Base > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t", "daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::batch > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t", "daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::distributed > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t", "daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::online > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t", "daal::services::SharedPtr< daal::algorithms::Analysis< daal::batch > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t", "daal::services::SharedPtr< daal::algorithms::Analysis< daal::distributed > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t", "daal::services::SharedPtr< daal::algorithms::Analysis< daal::online > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t = {"_p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t", "daal::services::SharedPtr< daal::algorithms::DistributedPredictionContainerIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t = {"_p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t", "daal::services::SharedPtr< daal::algorithms::DistributedPrediction > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t = {"_p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t", "daal::services::SharedPtr< daal::algorithms::PredictionContainerIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__Prediction_t = {"_p_daal__services__SharedPtrT_daal__algorithms__Prediction_t", "daal::services::SharedPtr< daal::algorithms::Prediction > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t", "daal::services::SharedPtr< daal::algorithms::Training< daal::batch > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t", "daal::services::SharedPtr< daal::algorithms::Training< daal::distributed > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t", "daal::services::SharedPtr< daal::algorithms::Training< daal::online > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__BatchBase_t = {"_p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__BatchBase_t", "daal::services::SharedPtr< daal::algorithms::engines::interface1::BatchBase > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__FamilyBatchBase_t = {"_p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__FamilyBatchBase_t", "daal::services::SharedPtr< daal::algorithms::engines::interface1::FamilyBatchBase > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__Input_t = {"_p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__Input_t", "daal::services::SharedPtr< daal::algorithms::engines::interface1::Input > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__Result_t = {"_p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__Result_t", "daal::services::SharedPtr< daal::algorithms::engines::interface1::Result > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__mt19937__interface1__BatchT_double_daal__algorithms__engines__mt19937__defaultDense_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__engines__mt19937__interface1__BatchT_double_daal__algorithms__engines__mt19937__defaultDense_t_t", "daal::services::SharedPtr< daal::algorithms::engines::mt19937::interface1::Batch< double,daal::algorithms::engines::mt19937::defaultDense > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__mt19937__interface1__BatchT_float_daal__algorithms__engines__mt19937__defaultDense_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__engines__mt19937__interface1__BatchT_float_daal__algorithms__engines__mt19937__defaultDense_t_t", "daal::services::SharedPtr< daal::algorithms::engines::mt19937::interface1::Batch< float,daal::algorithms::engines::mt19937::defaultDense > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIfaceImpl > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::batch > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::distributed > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::online > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::batch > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::distributed > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::online > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmDispatchContainer_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmDispatchContainer_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmDispatchContainer > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::batch > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::distributed > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::online > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::batch > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::distributed > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::online > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t", "daal::services::SharedPtr< daal::algorithms::interface1::Argument > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__HostAppIface_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__HostAppIface_t", "daal::services::SharedPtr< daal::algorithms::interface1::HostAppIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t", "daal::services::SharedPtr< daal::algorithms::interface1::Input > *|daal::algorithms::interface1::InputPtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Kernel_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__Kernel_t", "daal::services::SharedPtr< daal::algorithms::interface1::Kernel > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t", "daal::services::SharedPtr< daal::algorithms::interface1::Model > *|daal::algorithms::interface1::ModelPtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t", "daal::services::SharedPtr< daal::algorithms::interface1::OptionalArgument > *|daal::algorithms::interface1::OptionalArgumentPtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Parameter_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__Parameter_t", "daal::services::SharedPtr< daal::algorithms::interface1::Parameter > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t", "daal::algorithms::interface1::PartialResultPtr *|daal::services::SharedPtr< daal::algorithms::interface1::PartialResult > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t", "daal::algorithms::interface1::ResultPtr *|daal::services::SharedPtr< daal::algorithms::interface1::Result > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t", "daal::services::SharedPtr< daal::algorithms::interface1::SerializableArgument > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t", "daal::data_management::features::FeatureIdCollectionIfacePtr *|daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdCollectionIface > *|daal::data_management::features::interface1::FeatureIdCollectionIfacePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdCollection > *|daal::data_management::features::interface1::FeatureIdCollectionPtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdIface > *|daal::data_management::features::interface1::FeatureIdIfacePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdMappingIface > *|daal::data_management::features::interface1::FeatureIdMappingIfacePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdMapping > *|daal::data_management::features::interface1::FeatureIdMappingPtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureId > *|daal::data_management::features::interface1::FeatureIdPtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndexTraits_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndexTraits_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIndexTraits > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIndicesIface > *|daal::data_management::features::interface1::FeatureIndicesIfacePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIndices > *|daal::data_management::features::interface1::FeatureIndicesPtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BasicStatisticsDataCollection_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__BasicStatisticsDataCollection_t", "daal::services::SharedPtr< daal::data_management::interface1::BasicStatisticsDataCollection > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t", "daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > *|daal::data_management::interface1::CSRNumericTableIfacePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t", "daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *|daal::data_management::interface1::CSRNumericTablePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t", "daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CategoricalFeatureDictionary_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CategoricalFeatureDictionary_t", "daal::services::SharedPtr< daal::data_management::interface1::CategoricalFeatureDictionary > *|daal::data_management::interface1::CategoricalFeatureDictionaryPtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__ColumnFilter_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__ColumnFilter_t", "daal::services::SharedPtr< daal::data_management::interface1::ColumnFilter > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t", "daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t", "daal::services::SharedPtr< daal::data_management::interface1::CompressionIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t", "daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t", "daal::services::SharedPtr< daal::data_management::interface1::Compression > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t", "daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t", "daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t", "daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t", "daal::services::SharedPtr< daal::data_management::interface1::DataArchive > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t", "daal::services::SharedPtr< daal::data_management::interface1::DataBlockIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t", "daal::data_management::interface1::DataBlockPtr *|daal::services::SharedPtr< daal::data_management::interface1::DataBlock > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t", "daal::data_management::interface1::DataCollectionPtr *|daal::services::SharedPtr< daal::data_management::interface1::DataCollection > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t", "daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t", "daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t", "daal::services::SharedPtr< daal::data_management::interface1::DataSource > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t", "daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t", "daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t", "daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t", "daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t", "daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t", "daal::services::SharedPtr< daal::data_management::interface1::DictionaryIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *|daal::data_management::interface1::DataSourceDictionaryPtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t", "daal::data_management::interface1::NumericTableDictionaryPtr *|daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollectionIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollectionIface_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIdCollectionIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollection_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollection_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIdCollection > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdIface_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIdIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMappingIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMappingIface_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIdMappingIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMapping_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMapping_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIdMapping > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureId_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureId_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureId > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndexTraits_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndexTraits_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIndexTraits > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndicesIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndicesIface_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIndicesIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndices_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndices_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIndices > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t", "daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_const_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_const_t", "daal::data_management::interface1::KeyValueInputCollectionConstPtr *|daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t", "daal::data_management::interface1::KeyValueInputCollectionPtr *|daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t", "daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MakeCategorical_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__MakeCategorical_t", "daal::services::SharedPtr< daal::data_management::interface1::MakeCategorical > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t", "daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *|daal::data_management::interface1::MergedNumericTablePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__ModifierIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__ModifierIface_t", "daal::services::SharedPtr< daal::data_management::interface1::ModifierIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t", "daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t", "daal::data_management::interface1::NumericTableFeaturePtr *|daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t", "daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_const_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_const_t", "daal::data_management::interface1::NumericTableConstPtr *|daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t", "daal::data_management::interface1::NumericTablePtr *|daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__OneHotEncoder_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__OneHotEncoder_t", "daal::services::SharedPtr< daal::data_management::interface1::OneHotEncoder > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t", "daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t", "daal::data_management::interface1::RowMergedNumericTablePtr *|daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t", "daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *|daal::data_management::interface1::SOANumericTablePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_const_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_const_t", "daal::data_management::interface1::KeyValueDataCollectionConstPtr *|daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t", "daal::data_management::interface1::KeyValueDataCollectionPtr *|daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t", "daal::data_management::interface1::SerializationIfacePtr *|daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t", "daal::services::SharedPtr< daal::data_management::interface1::StringRowFeatureManagerIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t", "daal::services::SharedPtr< daal::data_management::interface1::TensorIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t", "daal::services::SharedPtr< daal::data_management::interface1::TensorLayoutIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t", "daal::data_management::interface1::TensorLayoutPtr *|daal::services::SharedPtr< daal::data_management::interface1::TensorLayout > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t", "daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t", "daal::data_management::interface1::TensorPtr *|daal::services::SharedPtr< daal::data_management::interface1::Tensor > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t", "daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::ConfigIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t", "daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Config > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t", "daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::ContextIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t", "daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Context > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t", "daal::data_management::modifiers::csv::interface1::FeatureModifierIfacePtr *|daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::FeatureModifierIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t", "daal::data_management::modifiers::csv::interface1::FeatureModifierPtr *|daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::FeatureModifier > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t", "daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::PyFeatureModifier > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t", "daal::services::SharedPtr< daal::data_management::modifiers::interface1::ConfigIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t", "daal::services::SharedPtr< daal::data_management::modifiers::interface1::ContextIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__backward__LayerIfacePtr_t_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__backward__LayerIfacePtr_t_t", "daal::services::SharedPtr< daal::services::interface1::Collection< daal::algorithms::neural_networks::layers::backward::LayerIfacePtr > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__LayerIfacePtr_t_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__LayerIfacePtr_t_t", "daal::services::SharedPtr< daal::services::interface1::Collection< daal::algorithms::neural_networks::layers::forward::LayerIfacePtr > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__interface1__LayerDescriptor_t_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__interface1__LayerDescriptor_t_t", "daal::services::SharedPtr< daal::services::interface1::Collection< daal::algorithms::neural_networks::layers::forward::interface1::LayerDescriptor > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__interface1__NextLayers_t_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__interface1__NextLayers_t_t", "daal::services::SharedPtr< daal::services::interface1::Collection< daal::algorithms::neural_networks::layers::interface1::NextLayers > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__data_management__interface1__SerializationIfacePtr_t_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__data_management__interface1__SerializationIfacePtr_t_t", "daal::services::SharedPtr< daal::services::interface1::Collection< daal::data_management::interface1::SerializationIfacePtr > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t", "daal::data_management::DataBlockCollectionPtr *|daal::services::SharedPtr< daal::services::interface1::Collection< daal::services::SharedPtr< daal::data_management::interface1::DataBlock > > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__Environment_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__Environment_t", "daal::services::SharedPtr< daal::services::interface1::Environment > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__ErrorCollection_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__ErrorCollection_t", "daal::services::interface1::ErrorCollectionPtr *|daal::services::SharedPtr< daal::services::interface1::ErrorCollection > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__Error_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__Error_t", "daal::services::interface1::ErrorPtr *|daal::services::SharedPtr< daal::services::interface1::Error > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__KernelErrorCollection_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__KernelErrorCollection_t", "daal::services::interface1::KernelErrorCollectionPtr *|daal::services::SharedPtr< daal::services::interface1::KernelErrorCollection > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t", "daal::services::SharedPtr< daal::services::interface1::LibraryVersionInfo > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t = {"_p_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t", "daal::services::interface1::Collection< daal::services::SharedPtr< daal::data_management::interface1::DataBlock > > *|daal::data_management::DataBlockCollection *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_env = {"_p_env", "env *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_first_type = {"_p_first_type", "first_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_numericTableType = {"_p_numericTableType", "numericTableType *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_second_type = {"_p_second_type", "second_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_size_t = {"_p_size_t", "size_t *|daal::data_management::features::interface1::FeatureIndex *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_super = {"_p_super", "super *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_unsigned_char = {"_p_unsigned_char", "unsigned char *|daal::byte *", 0, 0, (void*)0, 0};

static swig_type_info *swig_type_initial[] = {
  &_swigt__p_baseDataType,
  &_swigt__p_char,
  &_swigt__p_daal__data_management__features__interface1__FeatureIdCollection,
  &_swigt__p_daal__data_management__features__interface1__FeatureIdCollectionIface,
  &_swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t,
  &_swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t,
  &_swigt__p_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t,
  &_swigt__p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__Base_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__Prediction_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__BatchBase_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__FamilyBatchBase_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__Input_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__Result_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__mt19937__interface1__BatchT_double_daal__algorithms__engines__mt19937__defaultDense_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__mt19937__interface1__BatchT_float_daal__algorithms__engines__mt19937__defaultDense_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmDispatchContainer_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__HostAppIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Kernel_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Parameter_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndexTraits_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BasicStatisticsDataCollection_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CategoricalFeatureDictionary_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__ColumnFilter_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollectionIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollection_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMappingIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMapping_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureId_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndexTraits_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndicesIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndices_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_const_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MakeCategorical_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__ModifierIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_const_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__OneHotEncoder_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_const_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__backward__LayerIfacePtr_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__LayerIfacePtr_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__interface1__LayerDescriptor_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__interface1__NextLayers_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__data_management__interface1__SerializationIfacePtr_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__Environment_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__ErrorCollection_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__Error_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__KernelErrorCollection_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t,
  &_swigt__p_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t,
  &_swigt__p_env,
  &_swigt__p_first_type,
  &_swigt__p_numericTableType,
  &_swigt__p_second_type,
  &_swigt__p_size_t,
  &_swigt__p_super,
  &_swigt__p_unsigned_char,
};

static swig_cast_info _swigc__p_baseDataType[] = {  {&_swigt__p_baseDataType, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_char[] = {  {&_swigt__p_char, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__features__interface1__FeatureIdCollection[] = {{&_swigt__p_daal__data_management__features__interface1__FeatureIdCollection, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__features__interface1__FeatureIdCollectionIface[] = {  {&_swigt__p_daal__data_management__features__interface1__FeatureIdCollectionIface, 0, 0, 0},  {&_swigt__p_daal__data_management__features__interface1__FeatureIdCollection, _p_daal__data_management__features__interface1__FeatureIdCollectionTo_p_daal__data_management__features__interface1__FeatureIdCollectionIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t[] = {  {&_swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t[] = {  {&_swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t[] = {  {&_swigt__p_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t[] = {  {&_swigt__p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__Base_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t, _p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__Environment_t, _p_daal__services__SharedPtrT_daal__services__interface1__Environment_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__Base_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__Prediction_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__Prediction_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__BatchBase_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__BatchBase_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__FamilyBatchBase_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__FamilyBatchBase_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__Input_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__Input_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__Result_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__Result_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__engines__mt19937__interface1__BatchT_double_daal__algorithms__engines__mt19937__defaultDense_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__mt19937__interface1__BatchT_double_daal__algorithms__engines__mt19937__defaultDense_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__engines__mt19937__interface1__BatchT_float_daal__algorithms__engines__mt19937__defaultDense_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__engines__mt19937__interface1__BatchT_float_daal__algorithms__engines__mt19937__defaultDense_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t, _p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t, _p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t, _p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t, _p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t, _p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t, _p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t, _p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t, _p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmDispatchContainer_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmDispatchContainer_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t, _p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__Prediction_t, _p_daal__services__SharedPtrT_daal__algorithms__Prediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t, _p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__Prediction_t, _p_daal__services__SharedPtrT_daal__algorithms__Prediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__Prediction_t, _p_daal__services__SharedPtrT_daal__algorithms__Prediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t, _p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__Prediction_t, _p_daal__services__SharedPtrT_daal__algorithms__Prediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t, _p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t, _p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t, _p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t, _p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__HostAppIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__HostAppIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Kernel_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Kernel_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Parameter_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Parameter_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_tTo_p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndexTraits_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndexTraits_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BasicStatisticsDataCollection_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BasicStatisticsDataCollection_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CategoricalFeatureDictionary_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CategoricalFeatureDictionary_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__ColumnFilter_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__ColumnFilter_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollectionIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollectionIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollection_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollection_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMappingIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMappingIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMapping_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMapping_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureId_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureId_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndexTraits_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndexTraits_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndicesIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndicesIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndices_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndices_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_const_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_const_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MakeCategorical_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MakeCategorical_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__ModifierIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__ModifierIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_const_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_const_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__OneHotEncoder_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__OneHotEncoder_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_const_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_const_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t, _p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__backward__LayerIfacePtr_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__backward__LayerIfacePtr_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__LayerIfacePtr_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__LayerIfacePtr_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__interface1__LayerDescriptor_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__interface1__LayerDescriptor_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__interface1__NextLayers_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__interface1__NextLayers_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__data_management__interface1__SerializationIfacePtr_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__data_management__interface1__SerializationIfacePtr_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__Environment_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__Environment_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__ErrorCollection_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__ErrorCollection_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__Error_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__Error_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__KernelErrorCollection_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__KernelErrorCollection_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t[] = {  {&_swigt__p_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_env[] = {  {&_swigt__p_env, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_first_type[] = {  {&_swigt__p_first_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_numericTableType[] = {  {&_swigt__p_numericTableType, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_second_type[] = {  {&_swigt__p_second_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_size_t[] = {  {&_swigt__p_size_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_super[] = {  {&_swigt__p_super, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_unsigned_char[] = {  {&_swigt__p_unsigned_char, 0, 0, 0},{0, 0, 0, 0}};

static swig_cast_info *swig_cast_initial[] = {
  _swigc__p_baseDataType,
  _swigc__p_char,
  _swigc__p_daal__data_management__features__interface1__FeatureIdCollection,
  _swigc__p_daal__data_management__features__interface1__FeatureIdCollectionIface,
  _swigc__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t,
  _swigc__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t,
  _swigc__p_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t,
  _swigc__p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__Base_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__Prediction_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__BatchBase_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__FamilyBatchBase_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__Input_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__engines__interface1__Result_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__engines__mt19937__interface1__BatchT_double_daal__algorithms__engines__mt19937__defaultDense_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__engines__mt19937__interface1__BatchT_float_daal__algorithms__engines__mt19937__defaultDense_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmDispatchContainer_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__HostAppIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Kernel_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Parameter_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndexTraits_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BasicStatisticsDataCollection_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CategoricalFeatureDictionary_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__ColumnFilter_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollectionIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollection_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMappingIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMapping_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureId_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndexTraits_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndicesIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndices_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_const_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MakeCategorical_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__ModifierIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_const_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__OneHotEncoder_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_const_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__backward__LayerIfacePtr_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__LayerIfacePtr_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__interface1__LayerDescriptor_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__interface1__NextLayers_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__data_management__interface1__SerializationIfacePtr_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__Environment_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__ErrorCollection_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__Error_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__KernelErrorCollection_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t,
  _swigc__p_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t,
  _swigc__p_env,
  _swigc__p_first_type,
  _swigc__p_numericTableType,
  _swigc__p_second_type,
  _swigc__p_size_t,
  _swigc__p_super,
  _swigc__p_unsigned_char,
};


/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (END) -------- */

static swig_const_info swig_const_table[] = {
{0, 0, 0, 0.0, 0, 0}};

#ifdef __cplusplus
}
#endif
/* -----------------------------------------------------------------------------
 * Type initialization:
 * This problem is tough by the requirement that no dynamic
 * memory is used. Also, since swig_type_info structures store pointers to
 * swig_cast_info structures and swig_cast_info structures store pointers back
 * to swig_type_info structures, we need some lookup code at initialization.
 * The idea is that swig generates all the structures that are needed.
 * The runtime then collects these partially filled structures.
 * The SWIG_InitializeModule function takes these initial arrays out of
 * swig_module, and does all the lookup, filling in the swig_module.types
 * array with the correct data and linking the correct swig_cast_info
 * structures together.
 *
 * The generated swig_type_info structures are assigned statically to an initial
 * array. We just loop through that array, and handle each type individually.
 * First we lookup if this type has been already loaded, and if so, use the
 * loaded structure instead of the generated one. Then we have to fill in the
 * cast linked list. The cast data is initially stored in something like a
 * two-dimensional array. Each row corresponds to a type (there are the same
 * number of rows as there are in the swig_type_initial array). Each entry in
 * a column is one of the swig_cast_info structures for that type.
 * The cast_initial array is actually an array of arrays, because each row has
 * a variable number of columns. So to actually build the cast linked list,
 * we find the array of casts associated with the type, and loop through it
 * adding the casts to the list. The one last trick we need to do is making
 * sure the type pointer in the swig_cast_info struct is correct.
 *
 * First off, we lookup the cast->type name to see if it is already loaded.
 * There are three cases to handle:
 *  1) If the cast->type has already been loaded AND the type we are adding
 *     casting info to has not been loaded (it is in this module), THEN we
 *     replace the cast->type pointer with the type pointer that has already
 *     been loaded.
 *  2) If BOTH types (the one we are adding casting info to, and the
 *     cast->type) are loaded, THEN the cast info has already been loaded by
 *     the previous module so we just ignore it.
 *  3) Finally, if cast->type has not already been loaded, then we add that
 *     swig_cast_info to the linked list (because the cast->type) pointer will
 *     be correct.
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#if 0
} /* c-mode */
#endif
#endif

#if 0
#define SWIGRUNTIME_DEBUG
#endif


SWIGRUNTIME void
SWIG_InitializeModule(void *clientdata) {
  size_t i;
  swig_module_info *module_head, *iter;
  int init;
  
  /* check to see if the circular list has been setup, if not, set it up */
  if (swig_module.next==0) {
    /* Initialize the swig_module */
    swig_module.type_initial = swig_type_initial;
    swig_module.cast_initial = swig_cast_initial;
    swig_module.next = &swig_module;
    init = 1;
  } else {
    init = 0;
  }
  
  /* Try and load any already created modules */
  module_head = SWIG_GetModule(clientdata);
  if (!module_head) {
    /* This is the first module loaded for this interpreter */
    /* so set the swig module into the interpreter */
    SWIG_SetModule(clientdata, &swig_module);
  } else {
    /* the interpreter has loaded a SWIG module, but has it loaded this one? */
    iter=module_head;
    do {
      if (iter==&swig_module) {
        /* Our module is already in the list, so there's nothing more to do. */
        return;
      }
      iter=iter->next;
    } while (iter!= module_head);
    
    /* otherwise we must add our module into the list */
    swig_module.next = module_head->next;
    module_head->next = &swig_module;
  }
  
  /* When multiple interpreters are used, a module could have already been initialized in
       a different interpreter, but not yet have a pointer in this interpreter.
       In this case, we do not want to continue adding types... everything should be
       set up already */
  if (init == 0) return;
  
  /* Now work on filling in swig_module.types */
#ifdef SWIGRUNTIME_DEBUG
  printf("SWIG_InitializeModule: size %d\n", swig_module.size);
#endif
  for (i = 0; i < swig_module.size; ++i) {
    swig_type_info *type = 0;
    swig_type_info *ret;
    swig_cast_info *cast;
    
#ifdef SWIGRUNTIME_DEBUG
    printf("SWIG_InitializeModule: type %d %s\n", i, swig_module.type_initial[i]->name);
#endif
    
    /* if there is another module already loaded */
    if (swig_module.next != &swig_module) {
      type = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, swig_module.type_initial[i]->name);
    }
    if (type) {
      /* Overwrite clientdata field */
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: found type %s\n", type->name);
#endif
      if (swig_module.type_initial[i]->clientdata) {
        type->clientdata = swig_module.type_initial[i]->clientdata;
#ifdef SWIGRUNTIME_DEBUG
        printf("SWIG_InitializeModule: found and overwrite type %s \n", type->name);
#endif
      }
    } else {
      type = swig_module.type_initial[i];
    }
    
    /* Insert casting types */
    cast = swig_module.cast_initial[i];
    while (cast->type) {
      /* Don't need to add information already in the list */
      ret = 0;
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: look cast %s\n", cast->type->name);
#endif
      if (swig_module.next != &swig_module) {
        ret = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, cast->type->name);
#ifdef SWIGRUNTIME_DEBUG
        if (ret) printf("SWIG_InitializeModule: found cast %s\n", ret->name);
#endif
      }
      if (ret) {
        if (type == swig_module.type_initial[i]) {
#ifdef SWIGRUNTIME_DEBUG
          printf("SWIG_InitializeModule: skip old type %s\n", ret->name);
#endif
          cast->type = ret;
          ret = 0;
        } else {
          /* Check for casting already in the list */
          swig_cast_info *ocast = SWIG_TypeCheck(ret->name, type);
#ifdef SWIGRUNTIME_DEBUG
          if (ocast) printf("SWIG_InitializeModule: skip old cast %s\n", ret->name);
#endif
          if (!ocast) ret = 0;
        }
      }
      
      if (!ret) {
#ifdef SWIGRUNTIME_DEBUG
        printf("SWIG_InitializeModule: adding cast %s\n", cast->type->name);
#endif
        if (type->cast) {
          type->cast->prev = cast;
          cast->next = type->cast;
        }
        type->cast = cast;
      }
      cast++;
    }
    /* Set entry in modules->types array equal to the type */
    swig_module.types[i] = type;
  }
  swig_module.types[i] = 0;
  
#ifdef SWIGRUNTIME_DEBUG
  printf("**** SWIG_InitializeModule: Cast List ******\n");
  for (i = 0; i < swig_module.size; ++i) {
    int j = 0;
    swig_cast_info *cast = swig_module.cast_initial[i];
    printf("SWIG_InitializeModule: type %d %s\n", i, swig_module.type_initial[i]->name);
    while (cast->type) {
      printf("SWIG_InitializeModule: cast type %s\n", cast->type->name);
      cast++;
      ++j;
    }
    printf("---- Total casts: %d\n",j);
  }
  printf("**** SWIG_InitializeModule: Cast List ******\n");
#endif
}

/* This function will propagate the clientdata field of type to
* any new swig_type_info structures that have been added into the list
* of equivalent types.  It is like calling
* SWIG_TypeClientData(type, clientdata) a second time.
*/
SWIGRUNTIME void
SWIG_PropagateClientData(void) {
  size_t i;
  swig_cast_info *equiv;
  static int init_run = 0;
  
  if (init_run) return;
  init_run = 1;
  
  for (i = 0; i < swig_module.size; i++) {
    if (swig_module.types[i]->clientdata) {
      equiv = swig_module.types[i]->cast;
      while (equiv) {
        if (!equiv->converter) {
          if (equiv->type && !equiv->type->clientdata)
          SWIG_TypeClientData(equiv->type, swig_module.types[i]->clientdata);
        }
        equiv = equiv->next;
      }
    }
  }
}

#ifdef __cplusplus
#if 0
{
  /* c-mode */
#endif
}
#endif



#ifdef __cplusplus
extern "C" {
#endif
  
  /* Python-specific SWIG API */
#define SWIG_newvarlink()                             SWIG_Python_newvarlink()
#define SWIG_addvarlink(p, name, get_attr, set_attr)  SWIG_Python_addvarlink(p, name, get_attr, set_attr)
#define SWIG_InstallConstants(d, constants)           SWIG_Python_InstallConstants(d, constants)
  
  /* -----------------------------------------------------------------------------
   * global variable support code.
   * ----------------------------------------------------------------------------- */
  
  typedef struct swig_globalvar {
    char       *name;                  /* Name of global variable */
    PyObject *(*get_attr)(void);       /* Return the current value */
    int       (*set_attr)(PyObject *); /* Set the value */
    struct swig_globalvar *next;
  } swig_globalvar;
  
  typedef struct swig_varlinkobject {
    PyObject_HEAD
    swig_globalvar *vars;
  } swig_varlinkobject;
  
  SWIGINTERN PyObject *
  swig_varlink_repr(swig_varlinkobject *SWIGUNUSEDPARM(v)) {
#if PY_VERSION_HEX >= 0x03000000
    return PyUnicode_InternFromString("<Swig global variables>");
#else
    return PyString_FromString("<Swig global variables>");
#endif
  }
  
  SWIGINTERN PyObject *
  swig_varlink_str(swig_varlinkobject *v) {
#if PY_VERSION_HEX >= 0x03000000
    PyObject *str = PyUnicode_InternFromString("(");
    PyObject *tail;
    PyObject *joined;
    swig_globalvar *var;
    for (var = v->vars; var; var=var->next) {
      tail = PyUnicode_FromString(var->name);
      joined = PyUnicode_Concat(str, tail);
      Py_DecRef(str);
      Py_DecRef(tail);
      str = joined;
      if (var->next) {
        tail = PyUnicode_InternFromString(", ");
        joined = PyUnicode_Concat(str, tail);
        Py_DecRef(str);
        Py_DecRef(tail);
        str = joined;
      }
    }
    tail = PyUnicode_InternFromString(")");
    joined = PyUnicode_Concat(str, tail);
    Py_DecRef(str);
    Py_DecRef(tail);
    str = joined;
#else
    PyObject *str = PyString_FromString("(");
    swig_globalvar *var;
    for (var = v->vars; var; var=var->next) {
      PyString_ConcatAndDel(&str,PyString_FromString(var->name));
      if (var->next) PyString_ConcatAndDel(&str,PyString_FromString(", "));
    }
    PyString_ConcatAndDel(&str,PyString_FromString(")"));
#endif
    return str;
  }
  
  SWIGINTERN int
  swig_varlink_print(swig_varlinkobject *v, FILE *fp, int SWIGUNUSEDPARM(flags)) {
    char *tmp;
    PyObject *str = swig_varlink_str(v);
    fprintf(fp,"Swig global variables ");
    fprintf(fp,"%s\n", tmp = SWIG_Python_str_AsChar(str));
    SWIG_Python_str_DelForPy3(tmp);
    Py_DECREF(str);
    return 0;
  }
  
  SWIGINTERN void
  swig_varlink_dealloc(swig_varlinkobject *v) {
    swig_globalvar *var = v->vars;
    while (var) {
      swig_globalvar *n = var->next;
      free(var->name);
      free(var);
      var = n;
    }
  }
  
  SWIGINTERN PyObject *
  swig_varlink_getattr(swig_varlinkobject *v, char *n) {
    PyObject *res = NULL;
    swig_globalvar *var = v->vars;
    while (var) {
      if (strcmp(var->name,n) == 0) {
        res = (*var->get_attr)();
        break;
      }
      var = var->next;
    }
    if (res == NULL && !PyErr_Occurred()) {
      PyErr_Format(PyExc_AttributeError, "Unknown C global variable '%s'", n);
    }
    return res;
  }
  
  SWIGINTERN int
  swig_varlink_setattr(swig_varlinkobject *v, char *n, PyObject *p) {
    int res = 1;
    swig_globalvar *var = v->vars;
    while (var) {
      if (strcmp(var->name,n) == 0) {
        res = (*var->set_attr)(p);
        break;
      }
      var = var->next;
    }
    if (res == 1 && !PyErr_Occurred()) {
      PyErr_Format(PyExc_AttributeError, "Unknown C global variable '%s'", n);
    }
    return res;
  }
  
  SWIGINTERN PyTypeObject*
  swig_varlink_type(void) {
    static char varlink__doc__[] = "Swig var link object";
    static PyTypeObject varlink_type;
    static int type_init = 0;
    if (!type_init) {
      const PyTypeObject tmp = {
        /* PyObject header changed in Python 3 */
#if PY_VERSION_HEX >= 0x03000000
        PyVarObject_HEAD_INIT(NULL, 0)
#else
        PyObject_HEAD_INIT(NULL)
        0,                                  /* ob_size */
#endif
        (char *)"swigvarlink",              /* tp_name */
        sizeof(swig_varlinkobject),         /* tp_basicsize */
        0,                                  /* tp_itemsize */
        (destructor) swig_varlink_dealloc,  /* tp_dealloc */
        (printfunc) swig_varlink_print,     /* tp_print */
        (getattrfunc) swig_varlink_getattr, /* tp_getattr */
        (setattrfunc) swig_varlink_setattr, /* tp_setattr */
        0,                                  /* tp_compare */
        (reprfunc) swig_varlink_repr,       /* tp_repr */
        0,                                  /* tp_as_number */
        0,                                  /* tp_as_sequence */
        0,                                  /* tp_as_mapping */
        0,                                  /* tp_hash */
        0,                                  /* tp_call */
        (reprfunc) swig_varlink_str,        /* tp_str */
        0,                                  /* tp_getattro */
        0,                                  /* tp_setattro */
        0,                                  /* tp_as_buffer */
        0,                                  /* tp_flags */
        varlink__doc__,                     /* tp_doc */
        0,                                  /* tp_traverse */
        0,                                  /* tp_clear */
        0,                                  /* tp_richcompare */
        0,                                  /* tp_weaklistoffset */
#if PY_VERSION_HEX >= 0x02020000
        0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* tp_iter -> tp_weaklist */
#endif
#if PY_VERSION_HEX >= 0x02030000
        0,                                  /* tp_del */
#endif
#if PY_VERSION_HEX >= 0x02060000
        0,                                  /* tp_version */
#endif
#ifdef COUNT_ALLOCS
        0,0,0,0                             /* tp_alloc -> tp_next */
#endif
      };
      varlink_type = tmp;
      type_init = 1;
#if PY_VERSION_HEX < 0x02020000
      varlink_type.ob_type = &PyType_Type;
#else
      if (PyType_Ready(&varlink_type) < 0)
      return NULL;
#endif
    }
    return &varlink_type;
  }
  
  /* Create a variable linking object for use later */
  SWIGINTERN PyObject *
  SWIG_Python_newvarlink(void) {
    swig_varlinkobject *result = PyObject_NEW(swig_varlinkobject, swig_varlink_type());
    if (result) {
      result->vars = 0;
    }
    return ((PyObject*) result);
  }
  
  SWIGINTERN void 
  SWIG_Python_addvarlink(PyObject *p, char *name, PyObject *(*get_attr)(void), int (*set_attr)(PyObject *p)) {
    swig_varlinkobject *v = (swig_varlinkobject *) p;
    swig_globalvar *gv = (swig_globalvar *) malloc(sizeof(swig_globalvar));
    if (gv) {
      size_t size = strlen(name)+1;
      gv->name = (char *)malloc(size);
      if (gv->name) {
        strncpy(gv->name,name,size);
        gv->get_attr = get_attr;
        gv->set_attr = set_attr;
        gv->next = v->vars;
      }
    }
    v->vars = gv;
  }
  
  SWIGINTERN PyObject *
  SWIG_globals(void) {
    static PyObject *_SWIG_globals = 0; 
    if (!_SWIG_globals) _SWIG_globals = SWIG_newvarlink();  
    return _SWIG_globals;
  }
  
  /* -----------------------------------------------------------------------------
   * constants/methods manipulation
   * ----------------------------------------------------------------------------- */
  
  /* Install Constants */
  SWIGINTERN void
  SWIG_Python_InstallConstants(PyObject *d, swig_const_info constants[]) {
    PyObject *obj = 0;
    size_t i;
    for (i = 0; constants[i].type; ++i) {
      switch(constants[i].type) {
      case SWIG_PY_POINTER:
        obj = SWIG_InternalNewPointerObj(constants[i].pvalue, *(constants[i]).ptype,0);
        break;
      case SWIG_PY_BINARY:
        obj = SWIG_NewPackedObj(constants[i].pvalue, constants[i].lvalue, *(constants[i].ptype));
        break;
      default:
        obj = 0;
        break;
      }
      if (obj) {
        PyDict_SetItemString(d, constants[i].name, obj);
        Py_DECREF(obj);
      }
    }
  }
  
  /* -----------------------------------------------------------------------------*/
  /* Fix SwigMethods to carry the callback ptrs when needed */
  /* -----------------------------------------------------------------------------*/
  
  SWIGINTERN void
  SWIG_Python_FixMethods(PyMethodDef *methods,
    swig_const_info *const_table,
    swig_type_info **types,
    swig_type_info **types_initial) {
    size_t i;
    for (i = 0; methods[i].ml_name; ++i) {
      const char *c = methods[i].ml_doc;
      if (c && (c = strstr(c, "swig_ptr: "))) {
        int j;
        swig_const_info *ci = 0;
        const char *name = c + 10;
        for (j = 0; const_table[j].type; ++j) {
          if (strncmp(const_table[j].name, name, 
              strlen(const_table[j].name)) == 0) {
            ci = &(const_table[j]);
            break;
          }
        }
        if (ci) {
          void *ptr = (ci->type == SWIG_PY_POINTER) ? ci->pvalue : 0;
          if (ptr) {
            size_t shift = (ci->ptype) - types;
            swig_type_info *ty = types_initial[shift];
            size_t ldoc = (c - methods[i].ml_doc);
            size_t lptr = strlen(ty->name)+2*sizeof(void*)+2;
            char *ndoc = (char*)malloc(ldoc + lptr + 10);
            if (ndoc) {
              char *buff = ndoc;
              strncpy(buff, methods[i].ml_doc, ldoc);
              buff += ldoc;
              strncpy(buff, "swig_ptr: ", 10);
              buff += 10;
              SWIG_PackVoidPtr(buff, ptr, ty->name, lptr);
              methods[i].ml_doc = ndoc;
            }
          }
        }
      }
    }
  } 
  
#ifdef __cplusplus
}
#endif

/* -----------------------------------------------------------------------------*
 *  Partial Init method
 * -----------------------------------------------------------------------------*/

#ifdef __cplusplus
extern "C"
#endif

SWIGEXPORT 
#if PY_VERSION_HEX >= 0x03000000
PyObject*
#else
void
#endif
SWIG_init(void) {
  PyObject *m, *d, *md;
#if PY_VERSION_HEX >= 0x03000000
  static struct PyModuleDef SWIG_module = {
# if PY_VERSION_HEX >= 0x03020000
    PyModuleDef_HEAD_INIT,
# else
    {
      PyObject_HEAD_INIT(NULL)
      NULL, /* m_init */
      0,    /* m_index */
      NULL, /* m_copy */
    },
# endif
    (char *) SWIG_name,
    NULL,
    -1,
    SwigMethods,
    NULL,
    NULL,
    NULL,
    NULL
  };
#endif
  
#if defined(SWIGPYTHON_BUILTIN)
  static SwigPyClientData SwigPyObject_clientdata = {
    0, 0, 0, 0, 0, 0, 0
  };
  static PyGetSetDef this_getset_def = {
    (char *)"this", &SwigPyBuiltin_ThisClosure, NULL, NULL, NULL
  };
  static SwigPyGetSet thisown_getset_closure = {
    (PyCFunction) SwigPyObject_own,
    (PyCFunction) SwigPyObject_own
  };
  static PyGetSetDef thisown_getset_def = {
    (char *)"thisown", SwigPyBuiltin_GetterClosure, SwigPyBuiltin_SetterClosure, NULL, &thisown_getset_closure
  };
  PyObject *metatype_args;
  PyTypeObject *builtin_pytype;
  int builtin_base_count;
  swig_type_info *builtin_basetype;
  PyObject *tuple;
  PyGetSetDescrObject *static_getset;
  PyTypeObject *metatype;
  SwigPyClientData *cd;
  PyObject *public_interface, *public_symbol;
  PyObject *this_descr;
  PyObject *thisown_descr;
  PyObject *self = 0;
  int i;
  
  (void)builtin_pytype;
  (void)builtin_base_count;
  (void)builtin_basetype;
  (void)tuple;
  (void)static_getset;
  (void)self;
  
  /* metatype is used to implement static member variables. */
  metatype_args = Py_BuildValue("(s(O){})", "SwigPyObjectType", &PyType_Type);
  assert(metatype_args);
  metatype = (PyTypeObject *) PyType_Type.tp_call((PyObject *) &PyType_Type, metatype_args, NULL);
  assert(metatype);
  Py_DECREF(metatype_args);
  metatype->tp_setattro = (setattrofunc) &SwigPyObjectType_setattro;
  assert(PyType_Ready(metatype) >= 0);
#endif
  
  /* Fix SwigMethods to carry the callback ptrs when needed */
  SWIG_Python_FixMethods(SwigMethods, swig_const_table, swig_types, swig_type_initial);
  
#if PY_VERSION_HEX >= 0x03000000
  m = PyModule_Create(&SWIG_module);
#else
  m = Py_InitModule((char *) SWIG_name, SwigMethods);
#endif
  
  md = d = PyModule_GetDict(m);
  (void)md;
  
  SWIG_InitializeModule(0);
  
#ifdef SWIGPYTHON_BUILTIN
  SwigPyObject_stype = SWIG_MangledTypeQuery("_p_SwigPyObject");
  assert(SwigPyObject_stype);
  cd = (SwigPyClientData*) SwigPyObject_stype->clientdata;
  if (!cd) {
    SwigPyObject_stype->clientdata = &SwigPyObject_clientdata;
    SwigPyObject_clientdata.pytype = SwigPyObject_TypeOnce();
  } else if (SwigPyObject_TypeOnce()->tp_basicsize != cd->pytype->tp_basicsize) {
    PyErr_SetString(PyExc_RuntimeError, "Import error: attempted to load two incompatible swig-generated modules.");
# if PY_VERSION_HEX >= 0x03000000
    return NULL;
# else
    return;
# endif
  }
  
  /* All objects have a 'this' attribute */
  this_descr = PyDescr_NewGetSet(SwigPyObject_type(), &this_getset_def);
  (void)this_descr;
  
  /* All objects have a 'thisown' attribute */
  thisown_descr = PyDescr_NewGetSet(SwigPyObject_type(), &thisown_getset_def);
  (void)thisown_descr;
  
  public_interface = PyList_New(0);
  public_symbol = 0;
  (void)public_symbol;
  
  PyDict_SetItemString(md, "__all__", public_interface);
  Py_DECREF(public_interface);
  for (i = 0; SwigMethods[i].ml_name != NULL; ++i)
  SwigPyBuiltin_AddPublicSymbol(public_interface, SwigMethods[i].ml_name);
  for (i = 0; swig_const_table[i].name != 0; ++i)
  SwigPyBuiltin_AddPublicSymbol(public_interface, swig_const_table[i].name);
#endif
  
  SWIG_InstallConstants(d,swig_const_table);
  
  
  /* Initialize threading */
  SWIG_PYTHON_INITIALIZE_THREADS;
#if PY_VERSION_HEX >= 0x03000000
  return m;
#else
  return;
#endif
}

